package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@(!`0````````````(`/@`!````0"5```````!``````````#CH````
M`````````$``.``(`$``'``;``8````%````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````<`````````!P``````````0`````````!````
M!0````````````````!``````````$```````,S:````````S-H`````````
M`"````````$````&`````.``````````X&````````#@8```````V`0`````
M``!@%0``````````(````````@````8````HX````````"C@8```````*.!@
M``````#P`0```````/`!````````"``````````$````!````!P"````````
M'`)````````<`D```````"``````````(``````````$`````````%#E=&0$
M````>-4```````!XU4```````'C50```````%`$````````4`0````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````"``````````O;&EB-C0O;&0M;&EN=7@M>#@V+38T+G-O+C(`
M!````!`````!````1TY5```````"````!@````@`````````80```'(````*
M``````````````!!`````````$<```!&``````````````!8````/0```#<`
M```,````&@```%8`````````,````%T```!3````:````&H```!E````2@``
M`#X``````````````!<```!A````,0````````!N````8@```'````!C````
M"0````````!0````<0```"4```!,`````````$(`````````;P````````!/
M````0```````````````9`````L`````````*P``````````````;0```#,`
M``!#````10``````````````.P`````````_```````````````D````````
M`!\````=````/````$D````@````40``````````````60```$X````Y````
M&P```$L````N````,@`````````-````````````````````5````&L`````
M````1````%L````H````.@```"T`````````````````````````````````
M`````````````````````````````````````````````$T`````````!```
M`````````````P````````````````````4```````````````\`````````
M7``````````6``````````````!F`````````!``````````````````````
M````5P```````````````````!X`````````50`````````4`````````"\`
M```F````"```````````````)P````X````T````7P```"$````5````````
M```````J````'````&P````1``````````<`````````9P```"P`````````
M6@```"D`````````2`````8`````````:0``````````````````````````
M`````````",```````````````$`````````&````````````````````!,`
M`````````````%X`````````&0````````!2`````````!(`````````````
M``````!@````-0````(`````````(@```#@````V`````````"4```!-````
M!`````@````@$!``!4`$A*H"0`""E@&H0R@`($D@1`NXHCA-N@0&BDT```!.
M````````````````````40```%,```!4`````````%4```!6`````````%<`
M``!8````60````````!:````````````````````6P```%X`````````````
M`%\```!A````8@```&0`````````9@```&D`````````:P```&P```!M````
M;P````````#)U;)QYO\PHL[>1RVCX/M)IMVC:^O3[PXOQ9NVV\WCGH?YG(%K
M"4/6#3J7"\6)!9`-%.*>(?_D#K(!BV_$N9Q`:W^:?'^IG)MNQ=\?V7%8'+OC
MDGS49-1\K4OCP#)BV^WAIP(*9J_,9F`6R5E[\$IKXD?&`4-%U>Q'[#,Z?4&.
MQ<+E/RRW@(5D\MO3'?JA;&"YC?$.````````````````````````````````
MUP(``!(``````````````(0`````````L0```!(```````````````@`````
M````H0$``!(``````````````!4`````````D`,``!(``````````````.,*
M````````ZP(``!(``````````````&P`````````>@(``!(`````````````
M`(L%````````;0,``!(``````````````($!````````$0```"``````````
M````````````````(````"``````````````````````````C0$``!(`````
M``````````@`````````T0,``!(``````````````(,$````````(0,``!(`
M`````````````!4!````````;@$``!(```````````````@`````````@`$`
M`!(```````````````4`````````#P,``!(``````````````%\!````````
M``,``!(``````````````(``````````+@,``!(``````````````,4`````
M````D0(``!(``````````````-X!````````^`,``!(``````````````-@!
M````````+`(``!(``````````````#4$````````_0```!(`````````````
M`'T#````````'`(``!(``````````````%<`````````6`,``!(`````````
M`````"4`````````G@,``!(``````````````"4`````````R@$``!(`````
M`````````(\!````````=`,``!(``````````````#,`````````U00``!(`
M`````````````"4!````````F`(``!(``````````````#D!````````Z@$`
M`!(```````````````@`````````-0(``!(``````````````.H"````````
MI@$``!(``````````````"0!````````B0,``!(``````````````.D`````
M````JP,``!(``````````````)4`````````+P$``!(```````````````@`
M````````-````!(``````````````',`````````LP,``!(`````````````
M`#<`````````)@,``!(``````````````)``````````70$``!(`````````
M`````%`!````````R````!(``````````````+8&````````\0(``!(`````
M`````````(``````````EP,``!(``````````````#(!````````00$``!(`
M`````````````)@!````````R`,``!(``````````````"4`````````7`(`
M`!(``````````````!@#````````I`,``!(``````````````&4$````````
MX@,``!(``````````````)0!````````'@0``!(``````````````%,`````
M````3@(``!(``````````````.`3````````>P,``!(``````````````%<`
M````````JP$``!(``````````````,P`````````1P,``!(`````````````
M`!``````````\0,``!(``````````````"$`````````@@,``!(`````````
M`````/$`````````[````!(```````````````@`````````0@```!(`````
M``````````@`````````P0,``!(```````````````@`````````UP```!(`
M`````````````*4`````````_@$``!(```````````````@`````````/P,`
M`!(``````````````%4!````````%`0``!(``````````````%,`````````
MA0(``!(``````````````%L`````````^`(``!(``````````````(``````
M````4`$``!(``````````````*(`````````-@,``!(``````````````"T`
M````````'0$``!(```````````````@`````````Z@,``!(`````````````
M`"4`````````90,``!(``````````````'D#````````0P(``!(`````````
M`````+X"````````5````!(``````````````%``````````V`$``!(`````
M``````````@`````````8P```!(```````````````@`````````CP```!(`
M``````````````@`````````V`,``!(``````````````.``````````7P,`
M`!(``````````````"4`````````>````!(``````````````'``````````
M"P$``!(``````````````&@(````````MP$``!(```#8($```````#4`````
M````6P4``!$`#P#`>D```````+A:````````904``!(`#0"U84```````"((
M````````D04``!(`#0`&,4```````/$!````````#`0``"$`&0#@Y&``````
M``@`````````=P0``!(`#@"X=T``````````````````3P0``!(`#0"2+$``
M``````L`````````'04``!(`#0#0=D```````(D`````````H````!(```"H
M(D```````#4`````````"`4``!``&`"@Y&``````````````````"@4``"``
M&`"@Y&``````````````````"P0``"$`&0#@Y&````````@`````````;00`
M`!(`#0#`=D````````(`````````A`4``!(`#0"=+$```````,`"````````
MDP0``!(`#0#W,D```````&0`````````"@0``!$`&0#@Y&````````@`````
M````!00``!(`#0!X<T```````!P#````````PP0``!(`#0`S8$```````$,`
M````````W@0``!(`#0`\:T```````'@`````````/@0``!``\?_8Y&``````
M````````````2@0``!``\?]@]6``````````````````?00``!(`#0`W;D``
M`````.X$````````^00``!$`#P#@=T````````0`````````#@4``!(`#0!`
M)4``````````````````H00``!(`#0!P*T```````"(!````````MP0``!(`
M#0"N+T```````%@!````````Z@0``!$`&`#0Y&````````@`````````:@(`
M`!(```"8(D```````.X%````````8`0``!(`#0!=+T```````%$`````````
M-P0``!``\?_8Y&``````````````````5@4``!$`&`#(Y&````````@`````
M````+04``!(`#0#H;4```````$\`````````%04``!(`#0`L)D```````#D`
M````````204``!(`#0#7:4```````&4!````````HP(``!$`&0#PY&``````
M`!,`````````<@4``!(`#0!V8$```````#\!````````%P4``!(`"P!`($``
M`````````````````&QI8G!E<FPN<V\N-2XQ,`!?7V=M;VY?<W1A<G1?7P!?
M2G9?4F5G:7-T97)#;&%S<V5S`%!E<FQ?<WES7W1E<FT`4&5R;%])<W1A=&)U
M9E]P='(`4&5R;%]S>7-?:6YI=#,`4&5R;%])97AI=%]F;&%G<U]P='(`4&5R
M;%]S879E7V1E<W1R=6-T;W)?>`!097)L7TEC;VUP8W9?<'1R`%!E<FQ?871F
M;W)K7VQO8VL`4&5R;%])8W5R<W1A8VMI;F9O7W!T<@!P97)L7V-O;G-T<G5C
M=`!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7TEP87)S97)?<'1R`%!E<FQ?
M879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%])=&]P7V5N=E]P='(`
M4&5R;%])=&%I;G1E9%]P='(`4&5R;%]S=E]S971P=FX`4&5R;%]N97=35G!V
M`%!E<FQ?;F5W6%-?9FQA9W,`4&5R;%]):6Y?979A;%]P='(`4&5R;%]);W!?
M<'1R`%!E<FQ?265V86Q?<F]O=%]P='(`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T
M`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?1W1H<E]K
M97E?<'1R`%!E<FQ?1V1O7W5N9'5M<%]P='(`4&5R;%])<&5R;%]D97-T<G5C
M=%]L979E;%]P='(`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?9&]U
M;G=I;F0`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`
M8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C
M`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``;&EB9&PN<V\N,@!L:6)M+G-O
M+C8`;&EB<'1H<F5A9"YS;RXP`'!T:')E861?9V5T<W!E8VEF:6,`8VQO<V4`
M;W!E;C8T`&QS965K-C0`<F5A9`!L:6)C+G-O+C8`7U]R96=I<W1E<E]A=&9O
M<FL`97AI=`!S<')I;G1F`'-T<FYC;7``8VQO<V5D:7(`<W1R;F-P>0!?7W-T
M86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P
M:60`<W1R9'5P`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!M
M96UC<'D`;W!E;F1I<@!?7V-T>7!E7V)?;&]C`&=E='5I9`!R96%D;&EN:P!E
M>&5C=G``<F5A9&1I<C8T`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?
M<W1A<G1?;6%I;@!?7V5N=FER;VX`7U]X<W1A=#8T`%]?;'AS=&%T-C0`;&EB
M8W)Y<'0N<V\N,0!?961A=&$`7U]B<W-?<W1A<G0`7V5N9`!P87)?8W5R<F5N
M=%]E>&5C`'!A<E]B87-E;F%M90!?7VQI8F-?8W-U7V9I;FD`6%-?26YT97)N
M86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P
M<F]C`'!A<E]D:7)N86UE`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A
M<E]C;&5A;G5P`'-I>F5?;&]A9%]M95\R`%])3U]S=&1I;E]U<V5D`%]?9&%T
M85]S=&%R=`!X<U]I;FET`%]?;&EB8U]C<W5?:6YI=`!84U]);G1E<FYA;'-?
M4$%27T-,14%24U1!0TL`<&%R7W)M=&UP9&ER`&YA;65?;&]A9%]M95\R`'!A
M<E]M:W1M<&1I<@!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`<&%R
M7VEN:71?96YV`$=,24)#7S(N-`!'3$E"0U\R+C,`1TQ)0D-?,BXS+C(`1TQ)
M0D-?,BXR+C4````"```````#``(````#``````````,``P``````!``"``,`
M`P`#``````````,``P````,``P`````````#``,``P``````!0`#```````"
M``,````#`````P`#``,````#````!@`#``,```````,```````,``P````(`
M```#`````P`#```````````````#``,``````````0`!``$``P`!``$``0``
M``$``0`#``$``0`!``,``0`!``$``0`!``$``0`!``$``0`!`````0`!``$`
M`0`!``$````!``$````!``0`!0,``!````!0````%&EI#0``!@">!0``$```
M`!-I:0T```4`J`4``!````!R&6D)```$`+(%```0````=1II"0```P"^!0``
M``````$``0#'`@``$`````````!U&FD)```"`+X%````````&.)@```````&
M````"```````````````X.1@```````%````7```````````````\.1@````
M```%````;P``````````````..)@```````'`````0``````````````0.)@
M```````'`````@``````````````2.)@```````'`````P``````````````
M4.)@```````'````!```````````````6.)@```````'````!0``````````
M````8.)@```````'````!@``````````````:.)@```````'````!P``````
M````````<.)@```````'````30``````````````>.)@```````'````"@``
M````````````@.)@```````'````"P``````````````B.)@```````'````
M#```````````````D.)@```````'````#0``````````````F.)@```````'
M````#@``````````````H.)@```````'````#P``````````````J.)@````
M```'````$```````````````L.)@```````'````$0``````````````N.)@
M```````'````$@``````````````P.)@```````'````$P``````````````
MR.)@```````'````%```````````````T.)@```````'````%0``````````
M````V.)@```````'````%@``````````````X.)@```````'````%P``````
M````````Z.)@```````'````&```````````````\.)@```````'````&0``
M````````````^.)@```````'````&@```````````````.-@```````'````
M&P``````````````".-@```````'````'```````````````$.-@```````'
M````'0``````````````&.-@```````'````'@``````````````(.-@````
M```'````'P``````````````*.-@```````'````(```````````````,.-@
M```````'````(0``````````````..-@```````'````(@``````````````
M0.-@```````'````(P``````````````2.-@```````'````)```````````
M````4.-@```````'````:```````````````6.-@```````'````50``````
M````````8.-@```````'````)0``````````````:.-@```````'````)@``
M````````````<.-@```````'````)P``````````````>.-@```````'````
M*```````````````@.-@```````'````*0``````````````B.-@```````'
M````*@``````````````D.-@```````'````*P``````````````F.-@````
M```'````+```````````````H.-@```````'````+0``````````````J.-@
M```````'````+@``````````````L.-@```````'````+P``````````````
MN.-@```````'````,```````````````P.-@```````'````,0``````````
M````R.-@```````'````,@``````````````T.-@```````'````,P``````
M````````V.-@```````'````-```````````````X.-@```````'````-0``
M````````````Z.-@```````'````-@``````````````\.-@```````'````
M-P``````````````^.-@```````'````.````````````````.1@```````'
M````.0``````````````".1@```````'````.@``````````````$.1@````
M```'````.P``````````````&.1@```````'````/```````````````(.1@
M```````'````/0``````````````*.1@```````'````/@``````````````
M,.1@```````'````/P``````````````..1@```````'````0```````````
M````0.1@```````'````00``````````````2.1@```````'````0@``````
M````````4.1@```````'````0P``````````````6.1@```````'````1```
M````````````8.1@```````'````10``````````````:.1@```````'````
M1@``````````````<.1@```````'````1P``````````````>.1@```````'
M````2```````````````@.1@```````'````20``````````````B.1@````
M```'````2@``````````````D.1@```````'````2P``````````````F.1@
M```````'````3```````````````2(/L".@C!0``Z+(%``#H+5<``$B#Q`C#
M_S7*P2``_R7,P2``#Q]``/\ERL$@`&@`````Z>#_____)<+!(`!H`0```.G0
M_____R6ZP2``:`(```#IP/____\ELL$@`&@#````Z;#_____):K!(`!H!```
M`.F@_____R6BP2``:`4```#ID/____\EFL$@`&@&````Z8#_____)9+!(`!H
M!P```.EP_____R6*P2``:`@```#I8/____\E@L$@`&@)````Z5#_____)7K!
M(`!H"@```.E`_____R5RP2``:`L```#I,/____\E:L$@`&@,````Z2#_____
M)6+!(`!H#0```.D0_____R5:P2``:`X```#I`/____\E4L$@`&@/````Z?#^
M____)4K!(`!H$````.G@_O___R5"P2``:!$```#IT/[___\E.L$@`&@2````
MZ<#^____)3+!(`!H$P```.FP_O___R4JP2``:!0```#IH/[___\E(L$@`&@5
M````Z9#^____)1K!(`!H%@```.F`_O___R42P2``:!<```#I</[___\E"L$@
M`&@8````Z6#^____)0+!(`!H&0```.E0_O___R7ZP"``:!H```#I0/[___\E
M\L`@`&@;````Z3#^____)>K`(`!H'````.D@_O___R7BP"``:!T```#I$/[_
M__\EVL`@`&@>````Z0#^____)=+`(`!H'P```.GP_?___R7*P"``:"````#I
MX/W___\EPL`@`&@A````Z=#]____);K`(`!H(@```.G`_?___R6RP"``:",`
M``#IL/W___\EJL`@`&@D````Z:#]____):+`(`!H)0```.F0_?___R6:P"``
M:"8```#I@/W___\EDL`@`&@G````Z7#]____)8K`(`!H*````.E@_?___R6"
MP"``:"D```#I4/W___\E>L`@`&@J````Z4#]____)7+`(`!H*P```.DP_?__
M_R5JP"``:"P```#I(/W___\E8L`@`&@M````Z1#]____)5K`(`!H+@```.D`
M_?___R52P"``:"\```#I\/S___\E2L`@`&@P````Z>#\____)4+`(`!H,0``
M`.G0_/___R4ZP"``:#(```#IP/S___\E,L`@`&@S````Z;#\____)2K`(`!H
M-````.F@_/___R4BP"``:#4```#ID/S___\E&L`@`&@V````Z8#\____)1+`
M(`!H-P```.EP_/___R4*P"``:#@```#I8/S___\E`L`@`&@Y````Z5#\____
M)?J_(`!H.@```.E`_/___R7ROR``:#L```#I,/S___\EZK\@`&@\````Z2#\
M____)>*_(`!H/0```.D0_/___R7:OR``:#X```#I`/S___\ETK\@`&@_````
MZ?#[____)<J_(`!H0````.G@^____R7"OR``:$$```#IT/O___\ENK\@`&A"
M````Z<#[____);*_(`!H0P```.FP^____R6JOR``:$0```#IH/O___\EHK\@
M`&A%````Z9#[____)9J_(`!H1@```.F`^____R62OR``:$<```#I</O___\E
MBK\@`&A(````Z6#[____)8*_(`!H20```.E0^____R5ZOR``:$H```#I0/O_
M__\E<K\@`&A+````Z3#[____)6J_(`!H3````.D@^___```````````Q[4F)
MT5Y(B>)(@^3P4%1)Q\#`=D``2,?!T'9``$C'QWAS0`#H#_S___20D$B#[`A(
MBP6AO"``2(7`=`+_T$B#Q`C#D)"0D)"0D)"0D)"0D%5(B>532(/L"(`]:+\@
M``!U2[@8X&``2(L58K\@`$@M$.!@`$C!^`-(C5C_2#G:<R4/'X``````2(U"
M`4B)!3V_(`#_%,40X&``2(L5+[\@`$@YVG+BQ@4;OR```4B#Q`A;R<-F9F8N
M#Q^$``````!52(,]%[H@``!(B>5T&K@`````2(7`=!"_(.!@`$F)P\E!_^,/
M'T``R<.0D%5(B>5(@^P02,=%^.AW0`"_`````.B"_O__BSCH&_K__TB)QTB+
M3?BZF")``+[R=T``Z$7^___)PU5(B>532('L.!```$B)M<CO__](B97`[___
M9$B+!"4H````2(E%Z#'`2(VUX.___[K_#P``OPYX0`#H=/S__XF%W.___X.]
MW.___P!^'HN%W.___X/H`4B8#[:$!>#O__^$P'4'@ZW<[___`8.]W.___P!^
M5(N%W.___TACT$B-O>#O__^^+P```.C4^?__2(7`=#6+A=SO__](8]B_````
M`.B\_?__BSCH5?G__TB)QTB-E>#O__](B[7([___2(G9Z-S[___K)[\`````
MZ)#]__^+..@I^?__2(G'2(N5P.___TB+M<CO___H@_K__TB+1>AD2#,$)2@`
M``!T!>@O_/__2('$.!```%O)PU5(B>5(@^Q`2(E]R$B)=?A(@WW(`'0,2(L%
M3[T@`$B%P'4-2,=%T`````#IO0```$B+1<A(B47@ZP5(@T7@`4B+5>`/M@*$
MP'0+2(M-X`^V`3P]=>5(BT7@B<)(BT7(B=$IP8G(B47<2(L%_KP@`$B)1>CK
M7DAC5=Q(BW7(2(M]\.A?^?__A<!U1$AC1=Q(`T7P#[8`/#UU-4B+5>A(BP7)
MO"``2(G12"G!2(G(2,'X`XG"2(M%^(D02&-%W$B#P`%(BU7P2`'"2(E5T.L?
M2(-%Z`A(BTWH2(L)2(E-\$B#??``=9!(QT70`````$B+1=#)PU5(B>5(@^P@
M2(E]Z$B-=?Q(BWWHN`````#H[_[__\G#54B)Y5-(@^Q(2(E]X$B)=;A(BU6X
M#[8"/#UU!4B#1;@!2(M]N.B8^?__B47T2(UU\$B+?>"X`````.BN_O__2(E%
MR$B#?<@`=$M(BWW(Z&_Y__](B<*+1?1(.<(/@B(!``!(BTVX#[8!2(M5R(@"
M2(M-R`^V`83`#Y7`2(-%R`%(@T6X`83`==G'1<0`````Z>@!``!(BP6^NR``
M2(E%V,=%U`````#K"4B#1=@(@T74`4B+5=A(BP)(A<!UZXL%UKL@`(7`=#N+
M1=2#P`)(F$B--,4`````2(L]>[L@`.@N^___2(D%;[L@`$B+!6B[(`!(A<!U
M:<=%Q/_____I>@$``,<%C;L@``$```"+1=2#P`)(F$B-/,4`````Z,#W__](
MB4782(-]V`!U#,=%Q/_____I1`$``$AC1=1(C13%`````$B+-0Z[(`!(BWW8
MZ&WY__](BTW82(D-^KH@`$B+%?.Z(`!(8T742(/``4C!X`-(C00"2,<`````
M`(M%U(E%\$B+1>!(B47(ZP5(@T7(`4B+5<@/M@*$P'0+2(M-R`^V`3P]=>5(
MBQ6JNB``BT7PB<!(P>`#2(T<`DB+1<B)PDB+1>")T2G!B<@#1?2#P`*)Q^@(
M]___2(D#2(L#2(7`=0S'1<3_____Z8P```!(BQ5BNB``BT7PB<!(P>`#2(T$
M`DB+`$B)1<CK!4B#1<@!2(M%X`^V`$B+5<B(`DB+3<@/M@&$P`^5P$B#1>`!
M@_`!A,!U"TB+5<@/M@(\/77+2(M-R,8!/4B#1<@!2(M5N`^V`DB+3<B(`4B+
M5<@/M@*$P`^5P$B#1<@!2(-%N`&$P'79QT7$`````(M%Q$B#Q$A;R<-52(GE
M2(/L($B)?>CK/$B+%;ZY(`"+1?Q(F$C!X`-(`<)(B57@2(M%X$B#P`A(BP!(
MBU7@2(D"2(M5X$B+`DB%P'0'2(-%X`CKVTB-=?Q(BWWHN`````#H"OS__TB%
MP'6MR<-52(GE2('L0"```&1(BP0E*````$B)1?@QP$C'A=#?__\`````Z$[V
M__](C;WP[___N2%X0`")PKXE>$``N`````#H`??__XF%W-___X.]W-___P!Y
M$$C'A<C?__\`````Z9\```!(C;7@W___2(V]\.___[H`$```Z"KW__^)A=S?
M__^#O=S?__\`>0U(QX7(W___`````.MKBX7<W___@\`!2&/XZ$WU__](B870
MW___2(.]T-___P!U#4C'A<C?__\`````ZSR+A=S?__](8]!(C;7@W___2(N]
MT-___^CC]O__BX7<W___2)A(`X70W___Q@``2(N5T-___TB)E<C?__](BX7(
MW___2(M5^&1(,Q0E*````'0%Z`CW___)PU5(B>7HU?[__\G#54B)Y4B![%`0
M``!(B;W([___2(FUP.___V1(BP0E*````$B)1?@QP+\Q>$``N`````#HDOO_
M_TB)A=CO__](BS7.MR``2(N]R.___^@*]O__2(7`="E(B[7([___OSIX0`"X
M`````.A]^___2(N5R.___TB)E;CO___I)`(``$B+O<CO___H(/7__XF%[.__
M_TB+-8.W(`!(B[W`[___Z'?V__](B87@[___Z<$!``!(BX7@[___#[8`A,!U
M"TC'A>#O__]'>$``2(.]V.___P!T-$B+M>#O__](B[W8[___Z"7V__^%P'4=
M2(LU*K<@`+\`````Z"#V__](B87@[___Z6H!``!(B[W@[___Z)CT__^)A>CO
M___K&8.MZ.___P&+A>CO__](F$@#A>#O___&``"+A>CO__](F$B#Z`%(`X7@
M[___#[802(L%PK8@``^V`#C"=,.+A>CO__^#P`$#A>SO__\]_P\``'XI2(NU
MR.___[\Z>$``N`````#H9?K__TB+A<CO__](B86X[___Z0P!``!(BPUUMB``
M2(N%R.___TB+E>#O__](C;WP[___28G`ODEX0`"X`````.A6]/__OP````#H
M7/;__XLXZ/7Q__](B<?H7?7__TB)QDB-O?#O___HUD@``(7`=6B_`````.@P
M]O__BSCHR?'__TB)Q^@Q]?__BT`8)0#P```]`(```'5`2(V]\.___[X!````
MZ,'U__^%P'4K2(VU\.___[\Z>$``N`````#HI?G__TB-O?#O___HB_3__TB)
MA;CO___K2DB+-;NU(`"_`````.BQ]/__2(F%X.___TB#O>#O__\`#X4Q_O__
M2(NUR.___[\Z>$``N`````#H5/G__TB+E<CO__](B96X[___2(N%N.___TB+
M5?AD2#,4)2@```!T!>@]]/__R<-52(GE2(E]Z$B+1>A(B47X2(M%Z$B)1?#K
M)DB+1?`/MA!(BP4KM2``#[8`.,)U#$B+1?!(@\`!2(E%^$B#1?`!2(M%\`^V
M`(3`=<](BT7XR<-52(GE2(/L($B)??A(@WWX`'0+2(M%^`^V`(3`=1._1WA`
M`.BB\___2(E%Z.DA`0``2(M]^.A@\O__2(/H`4B+5?A(`<)(B57PZP5(@VWP
M`4B+3?!(.TWX=AQ(BU7P#[8"2(L5FK0@``^V$CC0=-SK!4B#;?`!2(M-\$@[
M3?AV%4B+5?`/M@)(BQ5TM"``#[82.-!UW$B+3?!(.TWX=3I(BU7P#[8"2(L5
M5;0@``^V$CC0=1._1WA``.@,\___2(E%Z.F+````2(L]-+0@`.CW\O__2(E%
MZ.MY2(-M\`%(BTWP2#M-^'852(M5\`^V`DB+%0RT(``/MA(XT'3<2(M5\$B+
M1?A(B=%(*<%(B<A(@\`"2#T`$```=@I(QT7H`````.LN2(M5\$B+1?A(B=%(
M*<%(B<A(@\`!2(G"2(MU^+]`Y6``Z"#S__](QT7H0.5@`$B+1>C)PU5(B>5(
M@^Q`9$B+!"4H````2(E%^#'`2(L%W$<``$B)1=!(BP791P``2(E%V$B+!=9'
M``!(B47@2(L%TT<``$B)1>@/MP701P``9HE%\+]0>$``N`````#HJOG__[]@
M>$``N`````#HF_G__[\Q>$``N`````#HC/G__[]L>$``N`````#H??G__[]V
M>$``N`````#H;OG__[^`>$``N`````#H7_G__[\Z>$``N`````#H4/G__[^*
M>$``N`````#H0?G__[^3>$``N`````#H,OG__[^>>$``N`````#H?/;__TB)
M1<A(@WW(`'032(MUR+]V>$``N`````#H?O;__[^O>$``N`````#H3_;__TB)
M1<A(@WW(`'032(MUR+_!>$``N`````#H4?;__[_,>$``N`````#H(O;__TB)
M1<A(@WW(`'052(MUR+\Q>$``N`````#H)/;__^MIO]QX0`"X`````.CS]?__
M2(E%R$B#?<@`=!5(BW7(OVQX0`"X`````.CU]?__ZSI(C4702(/`$4B)1<A(
MBWW(N@H```"^[7A``.BF[O__A<!U%TB+1<A(C7`*OVQX0`"X`````.BY]?__
MOOAX0`"_4'A``+@`````Z*7U__](BT7X9$@S!"4H````=`7HH_#__\G#54B)
MY4B#[""+!;NQ(`"#^/]U2;]L>$``N`````#H3?7__TB)1?A(@WWX`'0?2(M%
M^`^V`(3`=!1(BT7X#[8`/#!T"<=%[`$```#K!\=%[`````"+1>R)!6VQ(`"+
M!6>Q(`#)PU5(B>5(@>QH`@``2(F]*/W__TB+A2C]__](@\`X2(E%\,=%_```
M``#IM````$B+1?!(BP!(B47H2(-%\`B+3?Q(BT7H2,'@&$B)PH/B_TB+1>A(
MP>`()0``_P!("<)(BT7H2,'H""4`_P``2`G"2(M%Z$C!Z!@E_P```$@)PDAC
MP4B)E,4P_?__2,%MZ""+1?R-2`%(BT7H2,'@&$B)PH/B_TB+1>A(P>`()0``
M_P!("<)(BT7H2,'H""4`_P``2`G"2(M%Z$C!Z!@E_P```$@)PDACP4B)E,4P
M_?__@T7\`H-]_`\/CD+____'1?P0````Z90```"+3?R+1?R#Z`-(F$B+E,4P
M_?__BT7\@^@(2)A(BX3%,/W__T@QPHM%_(/H#DB82(N$Q3#]__](,<*+1?R#
MZ!!(F$B+A,4P_?__2#'"2&/!2(F4Q3#]__^+3?R+1?Q(F$B+A,4P_?__2(T4
M`(M%_$B82(N$Q3#]__](P>@?2`G02(G"@^+_2&/!2(F4Q3#]__^#1?P!@WW\
M3P^.8O___TB+A2C]__](BP!(B47@2(N%*/W__TB+0`A(B4782(N%*/W__TB+
M0!!(B4702(N%*/W__TB+0!A(B47(2(N%*/W__TB+0"!(B47`2(V%,/W__TB)
M1;A(BT7@2(G"2,'B!4B+1>!(P>@;2`G02(G!@^'_2(M5T$B+1=A((<)(BT78
M2/?02"-%R$@)T$B-!`%(B<)(`U7`2(M%N$B+`$B-!`)(!9EY@EJ#X/](B47H
M2(-%N`A(BT782(G"2,'B'DB+1=A(P>@"2`G0@^#_2(E%V$B+1>A(B<)(P>(%
M2(M%Z$C!Z!M("=!(B<&#X?](BU782(M%X$@APDB+1>!(]]!((T702`G02(T$
M`4B)PD@#5<A(BT6X2(L`2(T$`D@%F7F"6H/@_TB)1<!(@T6X"$B+1>!(B<)(
MP>(>2(M%X$C!Z`)("="#X/](B47@2(M%P$B)PDC!X@5(BT7`2,'H&T@)T$B)
MP8/A_TB+5>!(BT7H2"'"2(M%Z$CWT$@C1=A("=!(C00!2(G"2`-5T$B+1;A(
MBP!(C00"2`69>8):@^#_2(E%R$B#1;@(2(M%Z$B)PDC!XAY(BT7H2,'H`D@)
MT(/@_TB)1>A(BT7(2(G"2,'B!4B+1<A(P>@;2`G02(G!@^'_2(M5Z$B+1<!(
M(<)(BT7`2/?02"-%X$@)T$B-!`%(B<)(`U782(M%N$B+`$B-!`)(!9EY@EJ#
MX/](B4702(-%N`A(BT7`2(G"2,'B'DB+1<!(P>@"2`G0@^#_2(E%P$B+1=!(
MB<)(P>(%2(M%T$C!Z!M("=!(B<&#X?](BU7`2(M%R$@APDB+1<A(]]!((T7H
M2`G02(T$`4B)PD@#5>!(BT6X2(L`2(T$`D@%F7F"6H/@_TB)1=A(@T6X"$B+
M1<A(B<)(P>(>2(M%R$C!Z`)("="#X/](B47(2(M%V$B)PDC!X@5(BT782,'H
M&T@)T$B)P8/A_TB+5<A(BT702"'"2(M%T$CWT$@C1<!("=!(C00!2(G"2`-5
MZ$B+1;A(BP!(C00"2`69>8):@^#_2(E%X$B#1;@(2(M%T$B)PDC!XAY(BT70
M2,'H`D@)T(/@_TB)1=!(BT7@2(G"2,'B!4B+1>!(P>@;2`G02(G!@^'_2(M5
MT$B+1=A((<)(BT782/?02"-%R$@)T$B-!`%(B<)(`U7`2(M%N$B+`$B-!`)(
M!9EY@EJ#X/](B47H2(-%N`A(BT782(G"2,'B'DB+1=A(P>@"2`G0@^#_2(E%
MV$B+1>A(B<)(P>(%2(M%Z$C!Z!M("=!(B<&#X?](BU782(M%X$@APDB+1>!(
M]]!((T702`G02(T$`4B)PD@#5<A(BT6X2(L`2(T$`D@%F7F"6H/@_TB)1<!(
M@T6X"$B+1>!(B<)(P>(>2(M%X$C!Z`)("="#X/](B47@2(M%P$B)PDC!X@5(
MBT7`2,'H&T@)T$B)P8/A_TB+5>!(BT7H2"'"2(M%Z$CWT$@C1=A("=!(C00!
M2(G"2`-5T$B+1;A(BP!(C00"2`69>8):@^#_2(E%R$B#1;@(2(M%Z$B)PDC!
MXAY(BT7H2,'H`D@)T(/@_TB)1>A(BT7(2(G"2,'B!4B+1<A(P>@;2`G02(G!
M@^'_2(M5Z$B+1<!((<)(BT7`2/?02"-%X$@)T$B-!`%(B<)(`U782(M%N$B+
M`$B-!`)(!9EY@EJ#X/](B4702(-%N`A(BT7`2(G"2,'B'DB+1<!(P>@"2`G0
M@^#_2(E%P$B+1=!(B<)(P>(%2(M%T$C!Z!M("=!(B<&#X?](BU7`2(M%R$@A
MPDB+1<A(]]!((T7H2`G02(T$`4B)PD@#5>!(BT6X2(L`2(T$`D@%F7F"6H/@
M_TB)1=A(@T6X"$B+1<A(B<)(P>(>2(M%R$C!Z`)("="#X/](B47(2(M%V$B)
MPDC!X@5(BT782,'H&T@)T$B)P8/A_TB+5<A(BT702"'"2(M%T$CWT$@C1<!(
M"=!(C00!2(G"2`-5Z$B+1;A(BP!(C00"2`69>8):@^#_2(E%X$B#1;@(2(M%
MT$B)PDC!XAY(BT702,'H`D@)T(/@_TB)1=!(BT7@2(G"2,'B!4B+1>!(P>@;
M2`G02(G!@^'_2(M5T$B+1=A((<)(BT782/?02"-%R$@)T$B-!`%(B<)(`U7`
M2(M%N$B+`$B-!`)(!9EY@EJ#X/](B47H2(-%N`A(BT782(G"2,'B'DB+1=A(
MP>@"2`G0@^#_2(E%V$B+1>A(B<)(P>(%2(M%Z$C!Z!M("=!(B<&#X?](BU78
M2(M%X$@APDB+1>!(]]!((T702`G02(T$`4B)PD@#5<A(BT6X2(L`2(T$`D@%
MF7F"6H/@_TB)1<!(@T6X"$B+1>!(B<)(P>(>2(M%X$C!Z`)("="#X/](B47@
M2(M%P$B)PDC!X@5(BT7`2,'H&T@)T$B)P8/A_TB+5>!(BT7H2"'"2(M%Z$CW
MT$@C1=A("=!(C00!2(G"2`-5T$B+1;A(BP!(C00"2`69>8):@^#_2(E%R$B#
M1;@(2(M%Z$B)PDC!XAY(BT7H2,'H`D@)T(/@_TB)1>A(BT7(2(G"2,'B!4B+
M1<A(P>@;2`G02(G!@^'_2(M5Z$B+1<!((<)(BT7`2/?02"-%X$@)T$B-!`%(
MB<)(`U782(M%N$B+`$B-!`)(!9EY@EJ#X/](B4702(-%N`A(BT7`2(G"2,'B
M'DB+1<!(P>@"2`G0@^#_2(E%P$B+1=!(B<)(P>(%2(M%T$C!Z!M("=!(B<&#
MX?](BU7`2(M%R$@APDB+1<A(]]!((T7H2`G02(T$`4B)PD@#5>!(BT6X2(L`
M2(T$`D@%F7F"6H/@_TB)1=A(@T6X"$B+1<A(B<)(P>(>2(M%R$C!Z`)("="#
MX/](B47(2(M%V$B)PDC!X@5(BT782,'H&T@)T$B)P8/A_TB+5<A(BT702"'"
M2(M%T$CWT$@C1<!("=!(C00!2(G"2`-5Z$B+1;A(BP!(C00"2`69>8):@^#_
M2(E%X$B#1;@(2(M%T$B)PDC!XAY(BT702,'H`D@)T(/@_TB)1=!(BT7@2(G"
M2,'B!4B+1>!(P>@;2`G02(G!@^'_2(M5T$B+1=A((<)(BT782/?02"-%R$@)
MT$B-!`%(B<)(`U7`2(M%N$B+`$B-!`)(!9EY@EJ#X/](B47H2(-%N`A(BT78
M2(G"2,'B'DB+1=A(P>@"2`G0@^#_2(E%V$B+1>A(B<)(P>(%2(M%Z$C!Z!M(
M"=!(B<&#X?](BU782(M%X$@APDB+1>!(]]!((T702`G02(T$`4B)PD@#5<A(
MBT6X2(L`2(T$`D@%F7F"6H/@_TB)1<!(@T6X"$B+1>!(B<)(P>(>2(M%X$C!
MZ`)("="#X/](B47@2(M%P$B)PDC!X@5(BT7`2,'H&T@)T$B)P8/A_TB+5>!(
MBT7H2#'02#-%V$B-!`%(B<)(`U702(M%N$B+`$B-!`)(!:'KV6Z#X/](B47(
M2(-%N`A(BT7H2(G"2,'B'DB+1>A(P>@"2`G0@^#_2(E%Z$B+1<A(B<)(P>(%
M2(M%R$C!Z!M("=!(B<&#X?](BU7H2(M%P$@QT$@S1>!(C00!2(G"2`-5V$B+
M1;A(BP!(C00"2`6AZ]EN@^#_2(E%T$B#1;@(2(M%P$B)PDC!XAY(BT7`2,'H
M`D@)T(/@_TB)1<!(BT702(G"2,'B!4B+1=!(P>@;2`G02(G!@^'_2(M5P$B+
M1<A(,=!(,T7H2(T$`4B)PD@#5>!(BT6X2(L`2(T$`D@%H>O9;H/@_TB)1=A(
M@T6X"$B+1<A(B<)(P>(>2(M%R$C!Z`)("="#X/](B47(2(M%V$B)PDC!X@5(
MBT782,'H&T@)T$B)P8/A_TB+5<A(BT702#'02#-%P$B-!`%(B<)(`U7H2(M%
MN$B+`$B-!`)(!:'KV6Z#X/](B47@2(-%N`A(BT702(G"2,'B'DB+1=!(P>@"
M2`G0@^#_2(E%T$B+1>!(B<)(P>(%2(M%X$C!Z!M("=!(B<&#X?](BU702(M%
MV$@QT$@S1<A(C00!2(G"2`-5P$B+1;A(BP!(C00"2`6AZ]EN@^#_2(E%Z$B#
M1;@(2(M%V$B)PDC!XAY(BT782,'H`D@)T(/@_TB)1=A(BT7H2(G"2,'B!4B+
M1>A(P>@;2`G02(G!@^'_2(M5V$B+1>!(,=!(,T702(T$`4B)PD@#5<A(BT6X
M2(L`2(T$`D@%H>O9;H/@_TB)1<!(@T6X"$B+1>!(B<)(P>(>2(M%X$C!Z`)(
M"="#X/](B47@2(M%P$B)PDC!X@5(BT7`2,'H&T@)T$B)P8/A_TB+5>!(BT7H
M2#'02#-%V$B-!`%(B<)(`U702(M%N$B+`$B-!`)(!:'KV6Z#X/](B47(2(-%
MN`A(BT7H2(G"2,'B'DB+1>A(P>@"2`G0@^#_2(E%Z$B+1<A(B<)(P>(%2(M%
MR$C!Z!M("=!(B<&#X?](BU7H2(M%P$@QT$@S1>!(C00!2(G"2`-5V$B+1;A(
MBP!(C00"2`6AZ]EN@^#_2(E%T$B#1;@(2(M%P$B)PDC!XAY(BT7`2,'H`D@)
MT(/@_TB)1<!(BT702(G"2,'B!4B+1=!(P>@;2`G02(G!@^'_2(M5P$B+1<A(
M,=!(,T7H2(T$`4B)PD@#5>!(BT6X2(L`2(T$`D@%H>O9;H/@_TB)1=A(@T6X
M"$B+1<A(B<)(P>(>2(M%R$C!Z`)("="#X/](B47(2(M%V$B)PDC!X@5(BT78
M2,'H&T@)T$B)P8/A_TB+5<A(BT702#'02#-%P$B-!`%(B<)(`U7H2(M%N$B+
M`$B-!`)(!:'KV6Z#X/](B47@2(-%N`A(BT702(G"2,'B'DB+1=!(P>@"2`G0
M@^#_2(E%T$B+1>!(B<)(P>(%2(M%X$C!Z!M("=!(B<&#X?](BU702(M%V$@Q
MT$@S1<A(C00!2(G"2`-5P$B+1;A(BP!(C00"2`6AZ]EN@^#_2(E%Z$B#1;@(
M2(M%V$B)PDC!XAY(BT782,'H`D@)T(/@_TB)1=A(BT7H2(G"2,'B!4B+1>A(
MP>@;2`G02(G!@^'_2(M5V$B+1>!(,=!(,T702(T$`4B)PD@#5<A(BT6X2(L`
M2(T$`D@%H>O9;H/@_TB)1<!(@T6X"$B+1>!(B<)(P>(>2(M%X$C!Z`)("="#
MX/](B47@2(M%P$B)PDC!X@5(BT7`2,'H&T@)T$B)P8/A_TB+5>!(BT7H2#'0
M2#-%V$B-!`%(B<)(`U702(M%N$B+`$B-!`)(!:'KV6Z#X/](B47(2(-%N`A(
MBT7H2(G"2,'B'DB+1>A(P>@"2`G0@^#_2(E%Z$B+1<A(B<)(P>(%2(M%R$C!
MZ!M("=!(B<&#X?](BU7H2(M%P$@QT$@S1>!(C00!2(G"2`-5V$B+1;A(BP!(
MC00"2`6AZ]EN@^#_2(E%T$B#1;@(2(M%P$B)PDC!XAY(BT7`2,'H`D@)T(/@
M_TB)1<!(BT702(G"2,'B!4B+1=!(P>@;2`G02(G!@^'_2(M5P$B+1<A(,=!(
M,T7H2(T$`4B)PD@#5>!(BT6X2(L`2(T$`D@%H>O9;H/@_TB)1=A(@T6X"$B+
M1<A(B<)(P>(>2(M%R$C!Z`)("="#X/](B47(2(M%V$B)PDC!X@5(BT782,'H
M&T@)T$B)P8/A_TB+5<A(BT702#'02#-%P$B-!`%(B<)(`U7H2(M%N$B+`$B-
M!`)(!:'KV6Z#X/](B47@2(-%N`A(BT702(G"2,'B'DB+1=!(P>@"2`G0@^#_
M2(E%T$B+1>!(B<)(P>(%2(M%X$C!Z!M("=!(B<&#X?](BU702(M%V$@QT$@S
M1<A(C00!2(G"2`-5P$B+1;A(BP!(C00"2`6AZ]EN@^#_2(E%Z$B#1;@(2(M%
MV$B)PDC!XAY(BT782,'H`D@)T(/@_TB)1=A(BT7H2(G"2,'B!4B+1>A(P>@;
M2`G02(G!@^'_2(M5V$B+1>!(,=!(,T702(T$`4B)PD@#5<A(BT6X2(L`2(T$
M`D@%H>O9;H/@_TB)1<!(@T6X"$B+1>!(B<)(P>(>2(M%X$C!Z`)("="#X/](
MB47@2(M%P$B)PDC!X@5(BT7`2,'H&T@)T$B)P8/A_TB+5>!(BT7H2#'02#-%
MV$B-!`%(B<)(`U702(M%N$B+`$B-!`)(!:'KV6Z#X/](B47(2(-%N`A(BT7H
M2(G"2,'B'DB+1>A(P>@"2`G0@^#_2(E%Z$B+1<A(B<)(P>(%2(M%R$C!Z!M(
M"=!(B<&#X?](BU7H2(M%P$@QT$@S1>!(C00!2(G"2`-5V$B+1;A(BP!(C00"
M2`6AZ]EN@^#_2(E%T$B#1;@(2(M%P$B)PDC!XAY(BT7`2,'H`D@)T(/@_TB)
M1<!(BT702(G"2,'B!4B+1=!(P>@;2`G02(G&@^;_2(M5Z$B+1<!("=!(B<%(
M(TW(2(M5Z$B+1<!((=!("<A(C00&2(G"2`-5X$B+1;A(BP!(`<*XW+P;CTB-
M!`*#X/](B4782(-%N`A(BT7(2(G"2,'B'DB+1<A(P>@"2`G0@^#_2(E%R$B+
M1=A(B<)(P>(%2(M%V$C!Z!M("=!(B<:#YO](BU7`2(M%R$@)T$B)P4@C3=!(
MBU7`2(M%R$@AT$@)R$B-!`9(B<)(`U7H2(M%N$B+`$@!PKC<O!N/2(T$`H/@
M_TB)1>!(@T6X"$B+1=!(B<)(P>(>2(M%T$C!Z`)("="#X/](B4702(M%X$B)
MPDC!X@5(BT7@2,'H&T@)T$B)QH/F_TB+5<A(BT702`G02(G!2"--V$B+5<A(
MBT702"'02`G(2(T$!DB)PD@#5<!(BT6X2(L`2`'"N-R\&X](C00"@^#_2(E%
MZ$B#1;@(2(M%V$B)PDC!XAY(BT782,'H`D@)T(/@_TB)1=A(BT7H2(G"2,'B
M!4B+1>A(P>@;2`G02(G&@^;_2(M5T$B+1=A("=!(B<%((TW@2(M5T$B+1=A(
M(=!("<A(C00&2(G"2`-5R$B+1;A(BP!(`<*XW+P;CTB-!`*#X/](B47`2(-%
MN`A(BT7@2(G"2,'B'DB+1>!(P>@"2`G0@^#_2(E%X$B+1<!(B<)(P>(%2(M%
MP$C!Z!M("=!(B<:#YO](BU782(M%X$@)T$B)P4@C3>A(BU782(M%X$@AT$@)
MR$B-!`9(B<)(`U702(M%N$B+`$@!PKC<O!N/2(T$`H/@_TB)1<A(@T6X"$B+
M1>A(B<)(P>(>2(M%Z$C!Z`)("="#X/](B47H2(M%R$B)PDC!X@5(BT7(2,'H
M&T@)T$B)QH/F_TB+5>!(BT7H2`G02(G!2"--P$B+5>!(BT7H2"'02`G(2(T$
M!DB)PD@#5=A(BT6X2(L`2`'"N-R\&X](C00"@^#_2(E%T$B#1;@(2(M%P$B)
MPDC!XAY(BT7`2,'H`D@)T(/@_TB)1<!(BT702(G"2,'B!4B+1=!(P>@;2`G0
M2(G&@^;_2(M5Z$B+1<!("=!(B<%((TW(2(M5Z$B+1<!((=!("<A(C00&2(G"
M2`-5X$B+1;A(BP!(`<*XW+P;CTB-!`*#X/](B4782(-%N`A(BT7(2(G"2,'B
M'DB+1<A(P>@"2`G0@^#_2(E%R$B+1=A(B<)(P>(%2(M%V$C!Z!M("=!(B<:#
MYO](BU7`2(M%R$@)T$B)P4@C3=!(BU7`2(M%R$@AT$@)R$B-!`9(B<)(`U7H
M2(M%N$B+`$@!PKC<O!N/2(T$`H/@_TB)1>!(@T6X"$B+1=!(B<)(P>(>2(M%
MT$C!Z`)("="#X/](B4702(M%X$B)PDC!X@5(BT7@2,'H&T@)T$B)QH/F_TB+
M5<A(BT702`G02(G!2"--V$B+5<A(BT702"'02`G(2(T$!DB)PD@#5<!(BT6X
M2(L`2`'"N-R\&X](C00"@^#_2(E%Z$B#1;@(2(M%V$B)PDC!XAY(BT782,'H
M`D@)T(/@_TB)1=A(BT7H2(G"2,'B!4B+1>A(P>@;2`G02(G&@^;_2(M5T$B+
M1=A("=!(B<%((TW@2(M5T$B+1=A((=!("<A(C00&2(G"2`-5R$B+1;A(BP!(
M`<*XW+P;CTB-!`*#X/](B47`2(-%N`A(BT7@2(G"2,'B'DB+1>!(P>@"2`G0
M@^#_2(E%X$B+1<!(B<)(P>(%2(M%P$C!Z!M("=!(B<:#YO](BU782(M%X$@)
MT$B)P4@C3>A(BU782(M%X$@AT$@)R$B-!`9(B<)(`U702(M%N$B+`$@!PKC<
MO!N/2(T$`H/@_TB)1<A(@T6X"$B+1>A(B<)(P>(>2(M%Z$C!Z`)("="#X/](
MB47H2(M%R$B)PDC!X@5(BT7(2,'H&T@)T$B)QH/F_TB+5>!(BT7H2`G02(G!
M2"--P$B+5>!(BT7H2"'02`G(2(T$!DB)PD@#5=A(BT6X2(L`2`'"N-R\&X](
MC00"@^#_2(E%T$B#1;@(2(M%P$B)PDC!XAY(BT7`2,'H`D@)T(/@_TB)1<!(
MBT702(G"2,'B!4B+1=!(P>@;2`G02(G&@^;_2(M5Z$B+1<!("=!(B<%((TW(
M2(M5Z$B+1<!((=!("<A(C00&2(G"2`-5X$B+1;A(BP!(`<*XW+P;CTB-!`*#
MX/](B4782(-%N`A(BT7(2(G"2,'B'DB+1<A(P>@"2`G0@^#_2(E%R$B+1=A(
MB<)(P>(%2(M%V$C!Z!M("=!(B<:#YO](BU7`2(M%R$@)T$B)P4@C3=!(BU7`
M2(M%R$@AT$@)R$B-!`9(B<)(`U7H2(M%N$B+`$@!PKC<O!N/2(T$`H/@_TB)
M1>!(@T6X"$B+1=!(B<)(P>(>2(M%T$C!Z`)("="#X/](B4702(M%X$B)PDC!
MX@5(BT7@2,'H&T@)T$B)QH/F_TB+5<A(BT702`G02(G!2"--V$B+5<A(BT70
M2"'02`G(2(T$!DB)PD@#5<!(BT6X2(L`2`'"N-R\&X](C00"@^#_2(E%Z$B#
M1;@(2(M%V$B)PDC!XAY(BT782,'H`D@)T(/@_TB)1=A(BT7H2(G"2,'B!4B+
M1>A(P>@;2`G02(G&@^;_2(M5T$B+1=A("=!(B<%((TW@2(M5T$B+1=A((=!(
M"<A(C00&2(G"2`-5R$B+1;A(BP!(`<*XW+P;CTB-!`*#X/](B47`2(-%N`A(
MBT7@2(G"2,'B'DB+1>!(P>@"2`G0@^#_2(E%X$B+1<!(B<)(P>(%2(M%P$C!
MZ!M("=!(B<:#YO](BU782(M%X$@)T$B)P4@C3>A(BU782(M%X$@AT$@)R$B-
M!`9(B<)(`U702(M%N$B+`$@!PKC<O!N/2(T$`H/@_TB)1<A(@T6X"$B+1>A(
MB<)(P>(>2(M%Z$C!Z`)("="#X/](B47H2(M%R$B)PDC!X@5(BT7(2,'H&T@)
MT$B)QH/F_TB+5>!(BT7H2`G02(G!2"--P$B+5>!(BT7H2"'02`G(2(T$!DB)
MPD@#5=A(BT6X2(L`2`'"N-R\&X](C00"@^#_2(E%T$B#1;@(2(M%P$B)PDC!
MXAY(BT7`2,'H`D@)T(/@_TB)1<!(BT702(G"2,'B!4B+1=!(P>@;2`G02(G&
M@^;_2(M5Z$B+1<!("=!(B<%((TW(2(M5Z$B+1<!((=!("<A(C00&2(G"2`-5
MX$B+1;A(BP!(`<*XW+P;CTB-!`*#X/](B4782(-%N`A(BT7(2(G"2,'B'DB+
M1<A(P>@"2`G0@^#_2(E%R$B+1=A(B<)(P>(%2(M%V$C!Z!M("=!(B<:#YO](
MBU7`2(M%R$@)T$B)P4@C3=!(BU7`2(M%R$@AT$@)R$B-!`9(B<)(`U7H2(M%
MN$B+`$@!PKC<O!N/2(T$`H/@_TB)1>!(@T6X"$B+1=!(B<)(P>(>2(M%T$C!
MZ`)("="#X/](B4702(M%X$B)PDC!X@5(BT7@2,'H&T@)T$B)P8/A_TB+5=!(
MBT782#'02#-%R$B-!`%(B<)(`U7`2(M%N$B+`$@!PKC6P6+*2(T$`H/@_TB)
M1>A(@T6X"$B+1=A(B<)(P>(>2(M%V$C!Z`)("="#X/](B4782(M%Z$B)PDC!
MX@5(BT7H2,'H&T@)T$B)P8/A_TB+5=A(BT7@2#'02#-%T$B-!`%(B<)(`U7(
M2(M%N$B+`$@!PKC6P6+*2(T$`H/@_TB)1<!(@T6X"$B+1>!(B<)(P>(>2(M%
MX$C!Z`)("="#X/](B47@2(M%P$B)PDC!X@5(BT7`2,'H&T@)T$B)P8/A_TB+
M5>!(BT7H2#'02#-%V$B-!`%(B<)(`U702(M%N$B+`$@!PKC6P6+*2(T$`H/@
M_TB)1<A(@T6X"$B+1>A(B<)(P>(>2(M%Z$C!Z`)("="#X/](B47H2(M%R$B)
MPDC!X@5(BT7(2,'H&T@)T$B)P8/A_TB+5>A(BT7`2#'02#-%X$B-!`%(B<)(
M`U782(M%N$B+`$@!PKC6P6+*2(T$`H/@_TB)1=!(@T6X"$B+1<!(B<)(P>(>
M2(M%P$C!Z`)("="#X/](B47`2(M%T$B)PDC!X@5(BT702,'H&T@)T$B)P8/A
M_TB+5<!(BT7(2#'02#-%Z$B-!`%(B<)(`U7@2(M%N$B+`$@!PKC6P6+*2(T$
M`H/@_TB)1=A(@T6X"$B+1<A(B<)(P>(>2(M%R$C!Z`)("="#X/](B47(2(M%
MV$B)PDC!X@5(BT782,'H&T@)T$B)P8/A_TB+5<A(BT702#'02#-%P$B-!`%(
MB<)(`U7H2(M%N$B+`$@!PKC6P6+*2(T$`H/@_TB)1>!(@T6X"$B+1=!(B<)(
MP>(>2(M%T$C!Z`)("="#X/](B4702(M%X$B)PDC!X@5(BT7@2,'H&T@)T$B)
MP8/A_TB+5=!(BT782#'02#-%R$B-!`%(B<)(`U7`2(M%N$B+`$@!PKC6P6+*
M2(T$`H/@_TB)1>A(@T6X"$B+1=A(B<)(P>(>2(M%V$C!Z`)("="#X/](B478
M2(M%Z$B)PDC!X@5(BT7H2,'H&T@)T$B)P8/A_TB+5=A(BT7@2#'02#-%T$B-
M!`%(B<)(`U7(2(M%N$B+`$@!PKC6P6+*2(T$`H/@_TB)1<!(@T6X"$B+1>!(
MB<)(P>(>2(M%X$C!Z`)("="#X/](B47@2(M%P$B)PDC!X@5(BT7`2,'H&T@)
MT$B)P8/A_TB+5>!(BT7H2#'02#-%V$B-!`%(B<)(`U702(M%N$B+`$@!PKC6
MP6+*2(T$`H/@_TB)1<A(@T6X"$B+1>A(B<)(P>(>2(M%Z$C!Z`)("="#X/](
MB47H2(M%R$B)PDC!X@5(BT7(2,'H&T@)T$B)P8/A_TB+5>A(BT7`2#'02#-%
MX$B-!`%(B<)(`U782(M%N$B+`$@!PKC6P6+*2(T$`H/@_TB)1=!(@T6X"$B+
M1<!(B<)(P>(>2(M%P$C!Z`)("="#X/](B47`2(M%T$B)PDC!X@5(BT702,'H
M&T@)T$B)P8/A_TB+5<!(BT7(2#'02#-%Z$B-!`%(B<)(`U7@2(M%N$B+`$@!
MPKC6P6+*2(T$`H/@_TB)1=A(@T6X"$B+1<A(B<)(P>(>2(M%R$C!Z`)("="#
MX/](B47(2(M%V$B)PDC!X@5(BT782,'H&T@)T$B)P8/A_TB+5<A(BT702#'0
M2#-%P$B-!`%(B<)(`U7H2(M%N$B+`$@!PKC6P6+*2(T$`H/@_TB)1>!(@T6X
M"$B+1=!(B<)(P>(>2(M%T$C!Z`)("="#X/](B4702(M%X$B)PDC!X@5(BT7@
M2,'H&T@)T$B)P8/A_TB+5=!(BT782#'02#-%R$B-!`%(B<)(`U7`2(M%N$B+
M`$@!PKC6P6+*2(T$`H/@_TB)1>A(@T6X"$B+1=A(B<)(P>(>2(M%V$C!Z`)(
M"="#X/](B4782(M%Z$B)PDC!X@5(BT7H2,'H&T@)T$B)P8/A_TB+5=A(BT7@
M2#'02#-%T$B-!`%(B<)(`U7(2(M%N$B+`$@!PKC6P6+*2(T$`H/@_TB)1<!(
M@T6X"$B+1>!(B<)(P>(>2(M%X$C!Z`)("="#X/](B47@2(M%P$B)PDC!X@5(
MBT7`2,'H&T@)T$B)P8/A_TB+5>!(BT7H2#'02#-%V$B-!`%(B<)(`U702(M%
MN$B+`$@!PKC6P6+*2(T$`H/@_TB)1<A(@T6X"$B+1>A(B<)(P>(>2(M%Z$C!
MZ`)("="#X/](B47H2(M%R$B)PDC!X@5(BT7(2,'H&T@)T$B)P8/A_TB+5>A(
MBT7`2#'02#-%X$B-!`%(B<)(`U782(M%N$B+`$@!PKC6P6+*2(T$`H/@_TB)
M1=!(@T6X"$B+1<!(B<)(P>(>2(M%P$C!Z`)("="#X/](B47`2(M%T$B)PDC!
MX@5(BT702,'H&T@)T$B)P8/A_TB+5<!(BT7(2#'02#-%Z$B-!`%(B<)(`U7@
M2(M%N$B+`$@!PKC6P6+*2(T$`H/@_TB)1=A(@T6X"$B+1<A(B<)(P>(>2(M%
MR$C!Z`)("="#X/](B47(2(M%V$B)PDC!X@5(BT782,'H&T@)T$B)P8/A_TB+
M5<A(BT702#'02#-%P$B-!`%(B<)(`U7H2(M%N$B+`$@!PKC6P6+*2(T$`H/@
M_TB)1>!(@T6X"$B+1=!(B<)(P>(>2(M%T$C!Z`)("="#X/](B4702(M%X$B)
MPDC!X@5(BT7@2,'H&T@)T$B)P8/A_TB+5=!(BT782#'02#-%R$B-!`%(B<)(
M`U7`2(M%N$B+`$@!PKC6P6+*2(T$`H/@_TB)1>A(@T6X"$B+1=A(B<)(P>(>
M2(M%V$C!Z`)("="#X/](B4782(M%Z$B)PDC!X@5(BT7H2,'H&T@)T$B)P8/A
M_TB+5=A(BT7@2#'02#-%T$B-!`%(B<)(`U7(2(M%N$B+`$@!PKC6P6+*2(T$
M`H/@_TB)1<!(@T6X"$B+1>!(B<)(P>(>2(M%X$C!Z`)("="#X/](B47@2(N%
M*/W__TB+`$@#1<!(B<*#XO](BX4H_?__2(D02(N%*/W__TB+0`A(`T7H2(G"
M@^+_2(N%*/W__TB)4`A(BX4H_?__2(M`$$@#1>!(B<*#XO](BX4H_?__2(E0
M$$B+A2C]__](BT`82`-%V$B)PH/B_TB+A2C]__](B5`82(N%*/W__TB+0"!(
M`T702(G"@^+_2(N%*/W__TB)4"#)PU5(B>5(B7WX2(M%^$C'``$C16=(BT7X
MQT`(B:O-[\=`#`````!(BT7XQT`0_MRZF,=`%`````!(BT7X2,=`&'94,A!(
MBT7XQT`@\.'2P\=`)`````!(BT7X2,=`*`````!(BT7X2,=`,`````!(BT7X
MQT!X`````,G#54B)Y4B#[#!(B7WH2(EUX(E5W$B+1>A(BU`HBT7<2)A(P>`#
M2(T$`H/@_TB)1?!(BT7H2(M`*$@[1?!V%$B+1>A(BT`P2(U0`4B+1>A(B5`P
M2(M5Z$B+1?!(B4(H2(M%Z$B+4#"+1=Q(F$C!Z!U(`<)(BT7H2(E0,$B+1>B+
M0'B%P`^$IP```$B+1>B+4'BX0````"G0B47\BT7\.T7<?@:+1=R)1?R+1?Q(
M8\A(BT7H2(U0.$B+1>B+0'A(F$B-/`)(BW7@2(G*Z)_&__^+1?PI1=R+1?Q(
MF$@!1>!(BT7HBT!XB<(#5?Q(BT7HB5!X2(M%Z(M`>(/X0'5:2(M]Z.B+UO__
MZRA(BT7H2(UX.$B+=>"Z0````.A0QO__2(-%X$"#;=Q`2(M]Z.AAUO__@WW<
M/W_2BT7<2&/02(M%Z$B->#A(BW7@Z"'&__](BU7HBT7<B4)XR<-52(GE2(/L
M$$B)??A(B77P2(M]\.@?UO__2(M%\$B+`$C!Z!B)PDB+1?B($$B+1?A(C5`!
M2(M%\$B+`$C!Z!"(`DB+1?A(C5`"2(M%\$B+`$C!Z`B(`DB+1?A(C5`#2(M%
M\$B+`(@"2(M%^$B-4`1(BT7P2(M`"$C!Z!B(`DB+1?A(C5`%2(M%\$B+0`A(
MP>@0B`)(BT7X2(U0!DB+1?!(BT`(2,'H"(@"2(M%^$B-4`=(BT7P2(M`"(@"
M2(M%^$B-4`A(BT7P2(M`$$C!Z!B(`DB+1?A(C5`)2(M%\$B+0!!(P>@0B`)(
MBT7X2(U0"DB+1?!(BT`02,'H"(@"2(M%^$B-4`M(BT7P2(M`$(@"2(M%^$B-
M4`Q(BT7P2(M`&$C!Z!B(`DB+1?A(C5`-2(M%\$B+0!A(P>@0B`)(BT7X2(U0
M#DB+1?!(BT`82,'H"(@"2(M%^$B-4`](BT7P2(M`&(@"2(M%^$B-4!!(BT7P
M2(M`($C!Z!B(`DB+1?A(C5`12(M%\$B+0"!(P>@0B`)(BT7X2(U0$DB+1?!(
MBT`@2,'H"(@"2(M%^$B-4!-(BT7P2(M`((@"R<-52(GE2(/L,$B)?=A(B770
M2(M%T$B+0"A(B47P2(M%T$B+0#!(B47H2(M%\$C!Z`.#X#^)1?Q(BT702(U0
M.(M%_$B82(T$`L8`@(-%_`&#??PX?DNX0````"M%_$ACR$B+1=!(C5`XBT7\
M2)A(C3P"2(G*O@````#H/\'__TB+?=#H^=/__TB+1=!(C7@XNC@```"^````
M`.@?P?__ZRFX.````"M%_$ACR$B+1=!(C5`XBT7\2)A(C3P"2(G*O@````#H
M],#__TB+1>A(P>@8B<)(BT70B%!P2(M%Z$C!Z!")PDB+1="(4'%(BT7H2,'H
M"(G"2(M%T(A0<DB+1>B)PDB+1="(4'-(BT7P2,'H&(G"2(M%T(A0=$B+1?!(
MP>@0B<)(BT70B%!U2(M%\$C!Z`B)PDB+1="(4'9(BT7PB<)(BT70B%!W2(MU
MT$B+?=CH\OS__\G#54B)Y4B#["!(QT7P`````$C'1>@`````Z)C#__^)1?R#
M??P`=!>+??SHE\'__TB)1>A(BT7H2(L`2(E%\$B+1?#)PU5(B>532(/L:$B)
M?9A(QT7@`````$C'1=@`````2,=%H")Y0`!(QT6H,GE``$C'1;`Z>4``2,=%
MN$=Y0`!(QT7`3'E``$C'1<A>>4``2,=%T`````#'1>P`````Z;H```!(BWW@
MN`````#H@<?__TB)1=A(@WW8`'0+2(M%V`^V`(3`=11(BW682(M]X+@`````
MZ'G'___K?DB+=9A(BWW8Z-S!__](A<!U;$B+?9CH'L'__TB)PTB+/82#(`#H
M#\'__T@!PTB+?=CH`\'__TB-!`-(C7@"Z!;`__](B4702(L-6X,@`$B+1=A(
MBU682(M]T$F)P+Y)>$``N`````#H/<'__TB+==!(BWW@N`````#H^<;__X-%
M[`&+1>Q(F$B+1,6@2(E%X$B+1>`/M@"$P`^%*?___TB#Q&A;R<-52(GE4TB!
M[+B!``!(B;U(?O__9$B+!"4H````2(E%Z#'`2,>%^'[__P````!(QX7P?O__
M`````$C'A>A^__\`````2,>%@'[__U]Y0`!(QX6(?O__9WE``$C'A9!^__]'
M>$``2,>%F'[__UYY0`!(QX50?O__P7A``$C'A5A^__]L>4``2,>%8'[__W-Y
M0`!(QX5H?O__>WE``$C'A7!^__^`>4``2,>%>'[__UYY0`!(QX6@?O__A'E`
M`$C'A:A^__^)>4``2,>%L'[__UYY0`!(QX7@?O__DGE``$C'A=A^__]>>4``
M2,>%T'[__P````!(QX7(?O__`````$C'A<!^__\`````QX4,?___`````+\Q
M>$``N`````#HC\7__TB)A>A^__](@[WH?O__`'0R2(N%Z'[__P^V`(3`="1(
MB[WH?O__Z'3]__](B[WH?O__Z&K`__](B85`?O__Z9@&``"X`````.@/_?__
M2(F%R'[__TB#O<A^__\`=7?'A1Q___\`````ZSQ(B[WP?O__N`````#H%,7_
M_TB)A>A^__](@[WH?O__`'032(N]Z'[__^@)P/__2(F%R'[__X.%''___P%(
M@[W(?O__`'4EBX4<?___2)A(BX3%H'[__TB)A?!^__](BX7P?O__#[8`A,!U
ME4B#O<A^__\`=0U(QX7(?O__EWE``.M:2(N%R'[__TB)A0!____K/.BPOO__
M2(L02(N%`'___P^V`$@/OL!(`<!(C00"#[<`#[?`@^`(A<!U"DB+A0!____&
M`%](@X4`?___`4B+A0!___\/M@"$P'6VQX4<?___`````.G1````2(N]\'[_
M_[@`````Z"G$__](B87H?O__2(.]Z'[__P`/A*0```"_`````.ALP/__BSCH
M!;S__TB)Q^AMO___2(G&2(N]Z'[__^CV$@``A<!U>+\`````Z$#`__^+..C9
MN___2(G'Z$&___^+0!@E`/```#T`0```="B_`````.@8P/__BSCHL;O__TB)
MQ^@9O___BT`8)0#P```]`*```'4H2(N]Z'[__[X"````Z*F___^%P'432(N]
MZ'[__^B)OO__2(F%^'[__X.%''___P%(@[WX?O__`'4IBX4<?___2)A(BX3%
M4'[__TB)A?!^__](BX7P?O__#[8`A,`/A?S^___'A1Q___\`````Z:L```"_
M`````.A_O___BSCH&+O__TB)Q^B`OO__2(G&2(N]Z'[__^@)$@``A<!U>+\`
M````Z%.___^+..CLNO__2(G'Z%2^__^+0!@E`/```#T`0```="B_`````.@K
MO___BSCHQ+K__TB)Q^@LOO__BT`8)0#P```]`*```'4H2(N]Z'[__[X"````
MZ+R^__^%P'432(N]Z'[__^B<O?__2(F%^'[__X.%''___P%(@[WX?O__`'4I
MBX4<?___2)A(BX3%@'[__TB)A>A^__](BX7H?O__#[8`A,`/A2+___](B[WX
M?O__Z!^\__^)PTB+O>!^___H$;S__P'#2(N]R'[__^@#O/__`<-(B[W8?O__
MZ/6[__^-!`,%``0``(F%#'___XN%#'___TAC^.CYNO__2(F%P'[__TB+#3-^
M(`!(BX7(?O__2(N5X'[__TB+M?A^__](B[W`?O__28G!28G02(GROIYY0`"X
M`````.@'O/__2(N]P'[__[[M`0``Z$:^__^_1WE``+@`````Z)7!__](B87H
M?O__2(N]Z'[__^B4O/__2(G&2(N%2'[__TB+..BGQ?__2(F%T'[__TB#O=!^
M__\`=1%(BX5(?O__2(L`2(F%T'[__[@`````Z-7+__^%P`^%"0(``$B+O=!^
M__^^`````+@`````Z*B[__^)A1A___^#O1A___\`#X3@`0``B[T8?___N@(`
M``!(Q\;N____Z-Z\__](C;4@?___B[T8?___N@8```#HQ[G__P^VA2!___^$
MP`^%L0````^VA2%___\\0P^%H@````^VA2)___\\00^%DP````^VA2-___\\
M0P^%A`````^VA21___\\2'5Y#[:%)7___SQ%=6Z+O1A___^Z`@```$C'QL;_
M___H7KS__TB-M2!___^+O1A___^Z*0```.A'N?__2(L-J'P@`$B+A=A^__](
MC94@?___2(NUP'[__TB+O<!^__])B<%)B=!(B?*^IWE``+@`````Z'RZ___I
M00$``$B-O2#____H!//__^L9BY44?___2(VU('___TB-O2#____H8_/__TB-
MM2!___^+O1A___^Z`(```.C)N/__B844?___@[T4?___`'_!B[T8?___Z`^X
M__](C;4@____2(U]T.@S]O__QX40?___`````.LWBX40?___2)@/MD0%T`^V
MT(N%$'___P'`2)A(C7V@2`''OK9Y0`"X`````.C3N?__@X40?___`8.]$'__
M_Q-^P,9%R`!(BPVP>R``2(N%V'[__TB-5:!(B[7`?O__2(N]P'[__TF)P4F)
MT$B)\KZG>4``N`````#HA[G__^M/OOAX0`"_;'A``+@`````Z#^____HG+C_
M_XG!2(LU6WL@`$B+A=A^__](BY7`?O__2(N]P'[__TF)P4&)R$B)\;Z[>4``
MN`````#H-KG__TB+M<!^__^_,7A``+@`````Z.Z^__](B[W`?O__Z-+V__](
MBY7`?O__2(F50'[__TB+A4!^__](BU7H9$@S%"4H````=`7HR[G__TB!Q+B!
M``!;R<-52(GE4TB![,@```!(B;TX____B;4T____2,=%T`````!(B[TX____
MZ%2X__](B47@2(-]X``/A!\!``#IXP```$B+1=A(C7@3OD=X0`#H?KG__X7`
M#X3)````2(M%V$B->!.^R7E``.ADN?__A<`/A*\```!(B[TX____Z/"W__^)
MPTB+1=A(C7@3Z.&W__^-!`.#P`*)1>R+1>Q(8_CH[;;__TB)1=!(BT782(U(
M$TB+E3C___](BWW0OLQY0`"X`````.@7N/__2(VU0/___TB+?=#HKPP``(/X
M_W0KBX58____)0#P```]`$```'49@[TT____`'002(M]T+X!````Z/C^___K
M"4B+?=#HSK;__TB+?=#H1;?__TC'1=``````2(M]X.CTN?__2(E%V$B#?=@`
M#X4%____2(M]X.A,N?__2(.]./___P!T#$B+O3C____HEK;__TB!Q,@```!;
MR<-52(GE2(/L($B)?>A(BWWHZ%W$__](B47X2(M]^.C_P___2(E%\+@`````
MZ(O'__^%P'1"2(-]Z`!T.TB+1>@/M@"$P'0P2(M]\+Z2>4``Z&BW__](.T7P
M=1Q(BWWHO@$```#H,_[__TB+??B^`````.@E_O__R<-52(GE4TB#[!A(B77P
MOP````#H_;C__XLXZ):T__](B<?HGK3__TB+`$B+6`B_`````.C=N/__BSCH
M=K3__TB)Q^@>M?__#[8`B$,@OP````#HOKC__XLXZ%>T__](B<?H7[3__TB+
M`$B+6`B_`````.B>N/__BSCH-[3__TB)Q^COM/__2(L`#[=`(&8E_P%FB4,B
MOP````#H=KC__XLXZ`^T__](B<?H%[3__TB+`$B+6`B_`````.A6N/__BSCH
M[[/__TB)Q[H`````OEYY0`#HS;?__TB)0RB_`````.@ON/__BSCHR+/__TB)
MQ^C0L___2(L`2(M8"+\`````Z`^X__^+..BHL___2(G'Z""T__](BP!(B4,P
MOP````#H[[?__XLXZ(BS__](B<?HD+/__TB+`$B+0`A(B47@OP````#HR[?_
M_XLXZ&2S__](B<?HO+;__TB+`$B%P'0IOP````#HJK?__XLXZ$.S__](B<?H
MF[;__TB+`$B+@*@```!(B47HZPA(QT7H`````$B+5>A(BT7@2(E0.+\`````
MZ&VW__^+..@&L___2(G'Z`ZS__](BP!(BT`(2,=`0`````"_`````.A%M___
MBSCHWK+__TB)Q^CFLO__2(L`2(M`"$C'0$@`````OP````#H';?__XLXZ+:R
M__](B<?HOK+__TB+`$B+6`B_`````.C]MO__BSCHEK+__TB)Q^B>MO__2(L`
M2(E#4$B#Q!A;R<-52(GE2(/L$$B)=?B_`````.C*MO__BSCH8[+__TB)Q[[_
M____Z!:T__^_`````.BLMO__BSCH1;+__TB)Q[H`````OK1K0`#HX[;__\G#
M54B)Y4%44TB#['!(B76HQT7H`````+\`````Z'&V__^+..@*LO__2(G'Z`*T
M___&``&_4'A``+@`````Z.ZY__](B47`2(-]P`!T&DB+1<`/M@`\,74/2(M%
MP$B#P`$/M@"$P'0*N`````#H7\+__[\`````Z!>V__^+..BPL?__2(G'N0L`
M``"Z`0```+[2>4``Z-FR__](B47@2(-]X``/A"P!``!(BT7@2(M`$$B+0"A(
MB478QT7L`0```.FZ````BT7LC5C_OP````#HOK7__XLXZ%>Q__](B<=(BW78
MN0````")VN@$M/__2(E%T$B#?=``#X20````2(M%T$B+`(M`#"4`!```A<!T
M$4B+1=!(BP!(BT`02(E%B.LQ2(M%T$B+&+\`````Z&"U__^+..CYL/__2(G'
MN0(```"Z`````$B)WNBDM?__2(E%B$B+%<F%(`"+1>Q(F$C!X`-(C00"2(LX
M2(MUB.@`M/__A<!U%X-%Z`&#1>P!BP66A2``.47L#XPW____BP6'A2``@^@!
M.T7H=3G'1>P!````ZR6_`````.CDM/__BSCH?;#__TB)QTB+==CHH;'__TB)
M1<B#1>P!BP5+A2``.47L?-"_`````.BTM/__BSCH3;#__TB)Q[D%````N@$`
M``"^UWE``.AVL?__2(E%X$B#?>``=&I(BT7@2(M`$$B+&+\`````Z':T__^+
M..@/L/__2(G'NMEY0`!(B=[H;['__TB+1>!(BT`02(L`BT`,)0``0`"%P'0G
M2(M%X$B+0!!(BQB_`````.@SM/__BSCHS*___TB)QTB)WNCALO__OP````#H
M%[3__XLXZ+"O__](B<>Y!0```+H!````OMYY0`#HV;#__TB)1>!(@WW@``^$
M@P```$C'1;@`````OSIX0`"X`````.AQM___2(E%N$B#?;@`="U(BT7@2(M`
M$$B+&+\`````Z+.S__^+..A,K___2(G'2(M5N$B)WNBML/__ZS1(BP4DA"``
M3(L@2(M%X$B+0!!(BQB_`````.A\L___BSCH%:___TB)QTR)XDB)WN@$M?__
MOP````#H7;/__XLXZ/:N__](B<?H[K#__\8``+\`````Z$&S__^+..C:KO__
M2(G'Z%*S__](QP``````OS%X0`"X`````.BZMO__2(D%E8,@`$B+!8Z#(`!(
MA<`/A1`!``!(BSV.@R``Z.;O__](B05R@R``2(L%>X,@`$B)19!(BT7@2(M`
M$$B+`(M`#"4`!```A<!T%4B+1>!(BT`02(L`2(M`$$B)19CK-4B+1>!(BT`0
M2(L8OP````#HIK+__XLXZ#^N__](B<>Y`@```+H`````2(G>Z.JR__](B468
M2(MUD$B+?9CHJ:[__XE%[$B+1>!(BT`02(L`BT`,)0`$``"%P'052(M%X$B+
M0!!(BP!(BT`02(E%H.LU2(M%X$B+0!!(BQB_`````.@ULO__BSCHSJW__TB)
MQ[D"````N@````!(B=[H>;+__TB)1:!(BP6>@B``2(LPBTWL2(M5H+_@>4``
MN`````#H);'__TB+/6Z"(`"^[0$``.@DLO__B47L@WWL`'0O@WWL$70I@WWL
M_W0C2(L52((@`$B+!5&"(`!(BS"+3>R_$'I``+@`````Z-RP__](@\1P6T%<
MR<-52(GEOP````#HE;'__XLXZ"ZM__](B<?HZK+__[\`````Z'RQ__^+..@5
MK?__2(G'0;D`````0;A>>4``N5YY0`"Z-VY``+Y>>D``Z%*O___)PU5(B>5(
M@^Q`B7WL2(EUX$B)5=A(C5782(UUX$B-?>SH'+'__[K8($``OM@@0`"_J")`
M`.CP`@``OP````#H7J[__P^V`(3`=4KH0J[__TB)!7.!(`!(BP5L@2``2(7`
M=0J_`0```.@EK?__2(L]5H$@`.CIKO__OP````#HS[#__XLXZ&BL__](B<?H
M`+#__\8``+\`````Z+.P__^+..A,K/__2(G'Z+2P__](B<(/M@*#R`*(`K\`
M````Z(^P__^+..@HK/__2(G'Z)"P__](B<(/M@*#R`&(`HM%[(/`!4B82(E%
MR$B#?<@`>`WR2`\J1<CR#Q%%T.LC2(M%R$C1Z$B+5<B#X@%("=#R2`\JP&8/
M*,CR#UC(\@\13=!F#U?`\@]81=!F#RX%V04```^7P(/P`83`=0^_\.1@`+@`
M````Z#BO__^+1>R#P`5(F$B-/,4`````Z&.O__](B05\@"``2(L5=8`@`$B+
M1>!(BP!(B0)(BP5D@"``2(/`"$C'`'-Z0`!(BP52@"``2(/`$$C'`,!Z0`#'
M!36`(``#````2(L5-H`@`(L%*(`@`$B82,'@`TB-!`)(QP!V>D``BP41@"``
M@\`!B04(@"``QT7X`0```.M+2(L-`(`@`(L%\G\@``-%^$ACT+@!````2"G0
M2(T4Q0````!(B=!(P>`]2"G02`'!2(M5X(M%^$B82,'@`TB-!`)(BP!(B0&#
M1?@!BT7L.47X?*U(BPVM?R``BU7LBP6<?R``C00"2&/0N`$```!(*=!(C13%
M`````$B)T$C!X#U(*=!(C00!2,<``````$B+#7)_(`"+5>R+!6%_(`"-!`*-
M4/](BSU$?R``0;@`````OB5S0`#HK*K__XE%_(-]_`!U#TB+/21_(`#H9ZO_
M_XE%_$B+/15_(`#H.*W__[]@>$``N`````#H)[+__TB%P'4Z2(L%_7X@`$B%
MP'46OS%X0`"X`````.@'LO__2(D%XGX@`$B+!=M^(`!(A<!T#$B+/<]^(`#H
MOO3__TB+/;M^(`#H_JG__^CIJ___BT7\R<.0D)"0D)"0D)"0D)!(C04!;B``
M,<E(A<!T!TB+#?-M(`#I?JK__Y"0D)"0D//#9F9F9F8N#Q^$``````!(B6PD
MV$R)?"3X2(TM'VD@`$R-/1AI(`!,B60DX$R);"3H3(ET)/!(B5PDT$B#[#A,
M*?U!B?Y)B?5(P?T#28G4Z"NI__](A>UT'#';#Q]``$R)XDR)[D2)]T'_%-](
M@\,!2#GK<NI(BUPD"$B+;"003(MD)!A,BVPD($R+="0H3(M\)#!(@\0XPY"0
MD)"0D)!(B?)(B?Z_`0```.FXK/__2(GR2(G^OP$```#IV*O__U5(B>532(/L
M"$B+!7!H(`!(@_C_=!F[`.!@``\?1```2(/K"/_02(L#2(/X_W7Q2(/$"%O)
MPY"02(/L".C/K?__2(/$",,```````````````````````````````````$`
M`@``````<&5R;'AS:2YC`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@`O
M<')O8R]S96QF+V5X90`O`#H`97AE`"]P<F]C+R5I+R5S`%!!4E]414U0`%!!
M4E]04D]'3D%-10`N`"5S)7,E<P!005)?24Y)5$E!3$E:140`4$%27U-005=.
M140`4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T%21T,`4$%2
M7T%21U9?,`!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!
M4E]435!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`4$%2
M7T-,14%./0`Q`````````%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@
M("`@``!,1%],24)205)97U!!5$@`3$E"4$%42`!,24)205)97U!!5$@`4$%4
M2`!$64Q$7TQ)0E)!4EE?4$%42```0SI<5$5-4``O=&UP`%1-4$1)4@!414U0
M1$E2`%1%35``5$U0`%5315(`55-%4DY!344`<&%R+0!365-414T`)7,E<R5S
M)7,`)7,E<V-A8VAE+25S)7,`)3`R>``E<R5S=&5M<"TE=25S`"XN`"5S+R5S
M`$%21U8`&`!P97)L`#``)7,Z(&5X96-U=&EO;B!O9B`E<R!F86EL960@+2!A
M8F]R=&EN9R!W:71H("5I+@H`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@=&5M
M<&]R87)Y('-U8F1I<F5C=&]R>2`E<R!F86EL960@+2!A8F]R=&EN9R!W:71H
M("5I+@H`26YT97)N86QS.CI005(Z.D)/3U0`+64`+2T`````````````````
M`,!#````````````````````````````````<&%R+G!L````````````````
M```````````````````C(2]U<W(O8FEN+W!E<FP*"F5V86P@)V5X96,@+W5S
M<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PH@("`@:68@,#L@(R!N;W0@
M<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"@IP86-K86=E(%]?<&%R7W!L.PH*
M(R`M+2T@5&AI<R!S8W)I<'0@;75S="!N;W0@=7-E(&%N>2!M;V1U;&5S(&%T
M(&-O;7!I;&4@=&EM92`M+2T*(R!U<V4@<W1R:6-T.PH*(VQI;F4@,34Y"@IM
M>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@
M*"1%3E9[4$%27T-,14%.?2D@>PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@
M("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@(')E<75I<F4@1FEL93HZ
M4W!E8SL*("`@(&UY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M
M92@D<&%R7W1E;7`I.PH@("`@;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B
M)'!A<E]T96UP(GTI.PH@("`@1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![
M("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["B`@("!R
M;61I<B`D<&%R7W1E;7`["B`@("!R;61I<B`D=&]P9&ER.PH*("`@(&EF("@M
M9"`D<&%R7W1E;7`I('L*("`@("`@("`C(%-O;65T:&EN9R!W96YT('=R;VYG
M('5N;&EN:VEN9R!T:&4@=&5M<&]R87)Y(&1I<F5C=&]R>2X@(%1H:7,*("`@
M("`@("`C('1Y<&EC86QL>2!H87!P96YS(&]N('!L871F;W)M<R!T:&%T(&1I
M<V%L;&]W('5N;&EN:VEN9R!S:&%R960*("`@("`@("`C(&QI8G)A<FEE<R!A
M;F0@97AE8W5T86)L97,@=&AA="!A<F4@:6X@=7-E+B!5;FQI;FL@=VET:"!A
M(&)A8VMG<F]U;F0*("`@("`@("`C('-H96QL(&-O;6UA;F0@<V\@=&AE(&9I
M;&5S(&%R92!N;R!L;VYG97(@:6X@=7-E(&)Y('1H:7,@<')O8V5S<RX*"B`@
M("`@("`@;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`H@("`@("`@("`@("!4
M14U03$%412`]/B`G=&UP6%A86%@G+`H@("`@("`@("`@("!$25(@/3X@1FEL
M93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"B`@("`@("`@("`@(%-5
M1D9)6"`]/B`G+F-M9"<L"B`@("`@("`@("`@(%5.3$E.2R`]/B`P+`H@("`@
M("`@("D["@H@("`@("`@(",@0F5C875S92!T:&4@<&%R7W1E;7`@9&ER96-T
M;W)Y(&ES(&=O:6YG('1O(&)E(&1E;&5T960@:6X@80H@("`@("`@(",@8F%C
M:V=R;W5N9"!P<F]C97-S+"!T:&4@<&%R96YT('!R;V-E<W,@:60@;6%Y(&)E
M(')E=7-E9"!B969O<F4@=&AE"B`@("`@("`@(R!B86-K9W)O=6YD('!R;V-E
M<W,@8V]M<&QE=&5S+B`@5&\@96YS=7)E('1H870@=&AE('1E;7!O<F%R>0H@
M("`@("`@(",@9&ER96-T;W)Y(&1O97,@;F]T(&=E="!R975S960@=VAI;&4@
M:70@:7,@8F5I;F<@9&5L971E9"P@=')Y('1O"B`@("`@("`@(R!R96YA;64@
M:70@=&\@82!N86UE('1H870@:7,@<F5L871E9"!T;R!T:&4@=&5M<&]R87)Y
M('-C<FEP="!F:6QE+@H*("`@("`@("!M>2`D=&UP;F%M92`]("A&:6QE.CI3
M<&5C+3YS<&QI='!A=&@H)'1M<"T^9FEL96YA;64I*5LR73L@(R!F:6QE;F%M
M90H@("`@("`@("1T;7!N86UE(#U^(',O7"Y;7BY=*B0O+F1I<B\["B`@("`@
M("`@;7D@)&YE=T1I<B`]($9I;&4Z.E-P96,M/F-A='!A=&@H"B`@("`@("`@
M("`@("A&:6QE.CI3<&5C+3YS<&QI='!A=&@H)'!A<E]T96UP*2E;,"XN,5TL
M("1T;7!N86UE*3L*("`@("`@("!I9B`H<F5N86UE("1P87)?=&5M<"P@)&YE
M=T1I<BD@>PH@("`@("`@("`@("!O=71S*")296YA;65D("1P87)?=&5M<"!T
M;R`D;F5W1&ER(BD["B`@("`@("`@("`@("1P87)?=&5M<"`]("1N97=$:7([
M"B`@("`@("`@?0H*("`@("`@("!I9B`H)%Y/(#U^(&TO=VEN,S(O:2D@>PH@
M("`@("`@("`@("!P<FEN="`D=&UP("(*.FQO;W`*<FUD:7(@+W$@+W,@7"(D
M<&%R7W1E;7!<(@II9B!E>&ES="!<(B1P87)?=&5M<%PB(&=O=&\@;&]O<`IR
M;61I<B!<(B1T;W!D:7)<(@IR;2!<(B(@+B`D=&UP+3YF:6QE;F%M92`N(")<
M(@HB.PH@("`@("`@("`@("!C;&]S92`D=&UP.PH@("`@("`@("`@("!M>2`D
M<')O8SL*("`@("`@("`@("`@5VEN,S(Z.E!R;V-E<W,Z.D-R96%T92@*("`@
M("`@("`@("`@("`@("1P<F]C+"`D14Y6>T-/35-014-]+`H@("`@("`@("`@
M("`@("`@(B1%3E9[0T]-4U!%0WT@+V,@7"(B("X@)'1M<"T^9FEL96YA;64@
M+B`B7"(@/FYU;"`R/FYU;"`B+`H@("`@("`@("`@("`@("`@,2P@3D]234%,
M7U!224]225197T-,05-3+"`B+B(*("`@("`@("`@("`@*3L*("`@("`@("!]
M(&5L<V4@>PH@("`@("`@("`@("!P<FEN="`D=&UP("(C(2]B:6XO<V@*=VAI
M;&4@6R`M9"`G)'!A<E]T96UP)R!=.R!D;PH@("!R;2`M<F8@)R1P87)?=&5M
M<"<*9&]N90IR;61I<B`G)'1O<&1I<B<*<FT@)R(@+B`D=&UP+3YF:6QE;F%M
M92`N("(G"B(["B`@("`@("`@("`@(&-H;6]D(#`W,#`L)'1M<"T^9FEL96YA
M;64["B`@("`@("`@("`@(&UY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@
M/B]D978O;G5L;"`R/B8Q("8G.PH@("`@("`@("`@("!C;&]S92`D=&UP.PH@
M("`@("`@("`@("!S>7-T96TH)&-M9"D["B`@("`@("`@?0H@("`@("`@(&]U
M=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C
M;&5A;G5P*2D["B`@("!]"GT@?0H*0D5'24X@>PH@("`@26YT97)N86QS.CI0
M05(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*
M"B`@("!E=F%L('L*"E]P87)?:6YI=%]E;G8H*3L*"FEF("AE>&ES=',@)$5.
M5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*("`@($!!
M4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[4$%2
M7T%21T-]("T@,2D["B`@("`D,"`]("1%3E9[4$%27T%21U9?,'T["GT*96QS
M92!["B`@("!F;W(@*&ME>7,@)45.5BD@>PH@("`@("`@(&1E;&5T92`D14Y6
M>R1??2!I9B`O7E!!4E]!4D=67R\["B`@("!]"GT*"FUY("1Q=6EE="`]("$D
M14Y6>U!!4E]$14)51WT["@HC(&9I>"`D<')O9VYA;64@:68@:6YV;VME9"!F
M<F]M(%!!5$@*;7D@)4-O;F9I9R`]("@*("`@('!A=&A?<V5P("`@(#T^("@D
M7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`H@("`@7V5X92`@("`@("`@
M/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z
M("<G*2P*("`@(%]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O
M(#\@)UQ<)R`Z("<O)RDL"BD["@I?<V5T7W!R;V=N86UE*"D["E]S971?<&%R
M7W1E;7`H*3L*"B,@36%G:6,@<W1R:6YG(&-H96-K:6YG(&%N9"!E>'1R86-T
M:6YG(&)U;F1L960@;6]D=6QE<R![>WL*;7D@*"1S=&%R=%]P;W,L("1D871A
M7W!O<RD["GL*("`@(&QO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PH*
M("`@(",@0VAE8VL@9FEL92!T>7!E+"!G970@<W1A<G0@;V8@9&%T82!S96-T
M:6]N('M[>PH@("`@;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0[
M"B`@("!B:6YM;V1E*%]&2"D["@H@("`@;7D@)&)U9CL*("`@('-E96L@7T9(
M+"`M."P@,CL*("`@(')E860@7T9(+"`D8G5F+"`X.PH@("`@;&%S="!U;FQE
M<W,@)&)U9B!E<2`B7&Y005(N<&U<;B(["@H@("`@<V5E:R!?1D@L("TQ,BP@
M,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@<V5E:R!?1D@L("TQ,B`M
M('5N<&%C:R@B3B(L("1B=68I+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#0[
M"@H@("`@)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["B`@("`C('U]?0H*
M("`@(",@17AT<F%C=&EN9R!E86-H(&9I;&4@:6YT;R!M96UO<GD@>WM["B`@
M("!M>2`E<F5Q=6ER95]L:7-T.PH@("`@=VAI;&4@*"1B=68@97$@(D9)3$4B
M*2!["B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A9"!?
M1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@("`@("!M>2`D9G5L
M;&YA;64@/2`D8G5F.PH@("`@("`@(&]U=',H<7$H56YP86-K:6YG(&9I;&4@
M(B1F=6QL;F%M92(N+BXI*3L*("`@("`@("!M>2`D8W)C(#T@*"`D9G5L;&YA
M;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PH@("`@
M("`@(&UY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I
M/R@N*BDH7"XN*BE\*3L*"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@
M("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@
M("`@("!I9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP
M;'QI>'QA;"DD+VDI('L*("`@("`@("`@("`@;7D@*"1O=70L("1F:6QE;F%M
M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD["B`@("`@("`@("`@(&EF("@D
M;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@
M("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("`@("`@8VQO
M<V4@)&]U=#L*("`@("`@("`@("`@("`@(&-H;6]D(#`W-34L("1F:6QE;F%M
M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B`@("`@("`@("`@("10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*
M("`@("`@("!]"B`@("`@("`@96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S
M:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PH@("`@("`@
M("`@("`C('-H;W5L9"!B92!M;W9E9"!T;R!?=&5M<&9I;&4H*0H@("`@("`@
M("`@("!M>2`D9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO)&)A<V5N86UE
M)&5X="(["B`@("`@("`@("`@(&]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I
M.PH@("`@("`@("`@("!O<&5N(&UY("1O=70L("<^)RP@)&9I;&5N86UE(&]R
M(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@
M("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("!C;&]S92`D;W5T.PH@
M("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)')E<75I<F5?
M;&ES='LD9G5L;&YA;65](#T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.DUO
M9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["B`@("`@("`@("`@("`@("!B=68@
M/3X@)&)U9BP*("`@("`@("`@("`@("`@(&-R8R`]/B`D8W)C+`H@("`@("`@
M("`@("`@("`@;F%M92`]/B`D9G5L;&YA;64L"B`@("`@("`@("`@('T["B`@
M("`@("`@?0H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@?0H@("`@
M(R!]?7T*"B`@("!L;V-A;"!`24Y#(#T@*'-U8B!["B`@("`@("`@;7D@*"1S
M96QF+"`D;6]D=6QE*2`]($!?.PH*("`@("`@("!R971U<FX@:68@<F5F("1M
M;V1U;&4@;W(@(21M;V1U;&4["@H@("`@("`@(&UY("1F:6QE;F%M92`](&1E
M;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*("`@("`@("`@
M("`@;7D@)&ME>3L*("`@("`@("`@("`@9F]R96%C:"`H:V5Y<R`E<F5Q=6ER
M95]L:7-T*2!["B`@("`@("`@("`@("`@("!N97AT('5N;&5S<R`O7%$D;6]D
M=6QE7$4D+SL*("`@("`@("`@("`@("`@("1K97D@/2`D7SL@;&%S=#L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD
M:V5Y?2!I9B!D969I;F5D*"1K97DI.PH@("`@("`@('T@;W(@<F5T=7)N.PH*
M("`@("`@("`D24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M
M;V1U;&4B.PH*("`@("`@("!I9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I
M;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PH@("`@("`@("`@("!M>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PH@("`@("`@("`@("!B
M:6YM;V1E*"1F:"D["B`@("`@("`@("`@('!R:6YT("1F:"`D9FEL96YA;64M
M/GMB=69].PH@("`@("`@("`@("!S965K*"1F:"P@,"P@,"D["B`@("`@("`@
M("`@(')E='5R;B`D9F@["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("!M>2`H)&]U="P@)&YA;64I(#T@7W1E;7!F:6QE*"<N<&TG+"`D
M9FEL96YA;64M/GMC<F-]*3L*("`@("`@("`@("`@:68@*"1O=70I('L*("`@
M("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@("!P
M<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@("`@("!C
M;&]S92`D;W5T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&]P96X@;7D@
M)&9H+"`G/"<L("1N86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D
M92@D9F@I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*"B`@
M("`@("`@9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@
M)&UO9'5L92%<;B(["B`@("!]+"!`24Y#*3L*"B`@("`C($YO=R!L;V%D(&%L
M;"!B=6YD;&5D(&9I;&5S('M[>PH*("`@(",@:6YI=&EA;&EZ92!S:&%R960@
M;V)J96-T('!R;V-E<W-I;F<*("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R
M97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@
M("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["@H@("`@(R!N;W<@;&5T)W,@=')Y(&=E='1I
M;F<@:&5L<&5R(&UO9'5L97,@9G)O;2!W:71H:6X*("`@(')E<75I<F4@24\Z
M.D9I;&4["@H@("`@(R!L;V%D(')E<W0@;V8@=&AE(&=R;W5P(&EN"B`@("!W
M:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T
M*5LP72D@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,
M15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@=6YL97-S("@D24Y#
M>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["B`@("`@
M("`@("`@(",@<F5Q=6ER92!M;V1U;&5S+"!D;R!O=&AE<B!E>&5C=71A8FQE
M(&9I;&5S"B`@("`@("`@("`@(&EF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O
M:2D@>PH@("`@("`@("`@("`@("`@<F5Q=6ER92`D9FEL96YA;64["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("`C
M(%-K:7`@06-T:79E4W1A=&4G<R!S:71E8W5S=&]M:7IE+G!L(&9I;&4Z"B`@
M("`@("`@("`@("`@("!D;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]
M?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PH@
M("`@?0H*("`@(",@?7U]"@H@("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<
M,#`S7#`P-"(["B`@("`D<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*
M(R!]?7T*"B,@07)G=6UE;G0@<')O8V5S<VEN9R![>WL*;7D@0'!A<E]A<F=S
M.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["@HD
M<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["@HC($1O;B=T('-W
M86QL;W<@87)G=6UE;G1S(&9O<B!C;VUP:6QE9"!E>&5C=71A8FQE<R!W:71H
M;W5T("TM<&%R+6]P=&EO;G,*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP
M72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["B`@("!M>2`E9&ES
M=%]C;60@/2!Q=R@*("`@("`@("!P("`@8FQI8E]T;U]P87(*("`@("`@("!I
M("`@:6YS=&%L;%]P87(*("`@("`@("!U("`@=6YI;G-T86QL7W!A<@H@("`@
M("`@(',@("!S:6=N7W!A<@H@("`@("`@('8@("!V97)I9GE?<&%R"B`@("`I
M.PH*("`@(&UY($!A9&1?=&]?:6YC.PH@("`@=VAI;&4@*$!!4D=6*2!["B`@
M("`@("`@)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@
M;W(@;&%S=#L*"B`@("`@("`@:68@*"0Q(&5Q("=))RD@>PH@("`@("`@("`@
M("!P=7-H($!A9&1?=&]?:6YC+"`D,CL*("`@("`@("!]"B`@("`@("`@96QS
M:68@*"0Q(&5Q("=-)RD@>PH@("`@("`@("`@("!E=F%L(")U<V4@)#(B.PH@
M("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)T$G*2!["B`@("`@("`@
M("`@('5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*("`@("`@("!]"B`@("`@("`@
M96QS:68@*"0Q(&5Q("=/)RD@>PH@("`@("`@("`@("`D;W5T(#T@)#(["B`@
M("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G8B<I('L*("`@("`@("`@
M("`@)&)U;F1L92`]("=S:71E)SL*("`@("`@("!]"B`@("`@("`@96QS:68@
M*"0Q(&5Q("=")RD@>PH@("`@("`@("`@("`D8G5N9&QE(#T@)V%L;"<["B`@
M("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G<2<I('L*("`@("`@("`@
M("`@)'%U:65T(#T@,3L*("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q
M("=,)RD@>PH@("`@("`@("`@("!O<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@
M9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PH@("`@("`@('T*("`@
M("`@("!E;'-I9B`H)#$@97$@)U0G*2!["B`@("`@("`@("`@("1C86-H95]N
M86UE(#T@)#(["B`@("`@("`@?0H*("`@("`@("!S:&EF="A`05)'5BD["@H@
M("`@("`@(&EF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PH@("`@("`@
M("`@("!D96QE=&4@)$5.5GLG4$%27U1%35`G?3L*("`@("`@("`@("`@:6YI
M=%]I;F,H*3L*("`@("`@("`@("`@<F5Q=6ER92!005(Z.D1I<W0["B`@("`@
M("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PH@
M("`@("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6
M.PH@("`@("`@("`@("!E>&ET.PH@("`@("`@('T*("`@('T*"B`@("!U;G-H
M:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"@HC(%A86"`M+2!A9&0@+2UP87(M
M9&5B=6<@<W5P<&]R="$*"B,@?7U]"@HC($]U='!U="!M;V1E("@M3RD@:&%N
M9&QI;F<@>WM["FEF("@D;W5T*2!["B`@("!["B`@("`@("`@(VQO8V%L("1)
M3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*
M("`@("`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@("`@(')E<75I<F4@07)C
M:&EV93HZ6FEP.PH@("`@?0H*"B`@("!M>2`D<&%R(#T@<VAI9G0H0$%21U8I
M.PH@("`@;7D@)'II<#L*"@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@
M("`@(&]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN
M9"`G)'!A<B<Z("0A(CL*("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@
M8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*"B`@("`@("`@)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PH@("`@("`@("@@)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*("`@
M("`@("`@("`@;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PH@("`@
M?0H*"B`@("!M>2`E96YV(#T@9&\@>PH@("`@("`@(&EF("@D>FEP(&%N9"!M
M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B`@("`@
M("`@("`@("1M971A(#U^(',O+BI><&%R.B0O+VUS.PH@("`@("`@("`@("`D
M;65T82`]?B!S+UY<4RXJ+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@+UX@
M("A;7CI=*RDZ("@N*RDD+VUG.PH@("`@("`@('T*("`@('T["@H@("`@(R!/
M<&5N(&EN<'5T(&%N9"!O=71P=70@9FEL97,@>WM["B`@("!L;V-A;"`D+R`]
M(%PT.PH*("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N(%!!
M4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PH@("`@("`@(&)I;FUO
M9&4H4$%2*3L*("`@("`@("!D:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B
M('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["B`@("!]"@H@("`@0W)E
M871E4&%T:"@D;W5T*2`["B`@("`*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN
M97<H"B`@("`@("`@)&]U="P*("`@("`@("!)3SHZ1FEL93HZ3U]#4D5!5"@I
M('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I
M+`H@("`@("`@(#`W-S<L"B`@("`I(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H
M)&9H*3L*"B`@("`D+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?
M<&]S(#H@=6YD968["B`@("!S965K(%]&2"P@,"P@,#L*("`@(&UY("1L;V%D
M97(@/2!S8V%L87(@/%]&2#X["B`@("!I9B`H(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*("`@("`@("!R
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@("`@("!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0H@("`@
M?0H@("`@9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PH@("`@
M("`@(&UY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B`@("`@("`@)'9A
M;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["B`@("`@("`@;7D@
M)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PH@("`@
M("`@(&UY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B`@
M("`@("`@)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PH@("`@("`@("`@("`D
M;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S
M970I*2D*("`@("`@("!]96<["B`@("!]"B`@("`D9F@M/G!R:6YT*"1L;V%D
M97(I.PH@("`@)"\@/2!U;F1E9CL*("`@(",@?7U]"@H@("`@(R!7<FET92!B
M=6YD;&5D(&UO9'5L97,@>WM["B`@("!I9B`H)&)U;F1L92D@>PH@("`@("`@
M(')E<75I<F4@4$%2.CI(96%V>3L*("`@("`@("!005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["B`@("`@("`@:6YI=%]I;F,H*3L*("`@("`@("!R
M97%U:7)E7VUO9'5L97,H*3L*"B`@("`@("`@;7D@0&EN8R`]('-O<G0@>PH@
M("`@("`@("`@("!L96YG=&@H)&(I(#P]/B!L96YG=&@H)&$I"B`@("`@("`@
M?2!G<F5P('L*("`@("`@("`@("`@(2]"4T1004XO"B`@("`@("`@?2!G<F5P
M('L*("`@("`@("`@("`@*"1B=6YD;&4@;F4@)W-I=&4G*2!O<@H@("`@("`@
M("`@("`H)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`H@
M("`@("`@("`@("`@)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]
M*3L*("`@("`@("!]($!)3D,["@H@("`@("`@(&EF("@D0V]N9FEG>U]D96QI
M;7T@97$@)UQ<)RD@>R!S>UQ<?7LO?6<@9F]R($!I;F,@?0H*("`@("`@("!M
M>2`E9FEL97,["B`@("`@("`@+UY?/"@N*RDD+R!A;F0@)&9I;&5S>R0Q?2LK
M(&9O<B!K97ES("4Z.CL*("`@("`@("`D9FEL97-[)%]]*RL@9F]R('9A;'5E
M<R`E24Y#.PH*("`@("`@("!M>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I
M9WML:6)?97AT?3L*("`@("`@("!M>2`E=W)I='1E;CL*"B`@("`@("`@9F]R
M96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PH@("`@("`@("`@("!M>2`H)&YA
M;64L("1F:6QE*3L*"B`@("`@("`@("`@(&9O<F5A8V@@;7D@)&1I<B`H0&EN
M8RD@>PH@("`@("`@("`@("`@("`@:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ
M.D9U;&Q#86-H97LD7WTI('L*("`@("`@("`@("`@("`@("`@("`D9FEL92`]
M("1?.PH@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>
M0V-=*2E<6B]I*2!["B`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M
M92D@/2`H)#$L("0R*3L*("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@
M("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS:68@*&TA7B]L;V%D
M97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["B`@("`@("`@("`@("`@("`@("`@
M:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"1R
M968L("0Q*3L*("`@("`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@96QS:68@*"UF
M("(D9&ER+R0Q(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`H)&9I;&4L
M("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@;&%S=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&YE>'0@=6YL97-S
M(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*("`@
M("`@("`@("`@;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN
M7%$D;&EB7V5X=%Q%)"\["B`@("`@("`@("`@(&]U=',H(&IO:6X@(B(L"B`@
M("`@("`@("`@("`@("!Q<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL
M92T^>VYA;65](#H@)&9I;&4L"B`@("`@("`@("`@("`@("!Q<2@B+BXN*0H@
M("`@("`@("`@("`I.PH*("`@("`@("`@("`@;7D@)&-O;G1E;G0["B`@("`@
M("`@("`@(&EF("AR968H)&9I;&4I*2!["B`@("`@("`@("`@("`@("`D8V]N
M=&5N="`]("1F:6QE+3Y[8G5F?3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!E;'-E('L*("`@("`@("`@("`@("`@(&]P96X@1DE,12P@)SPG+"`D9FEL
M92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*("`@("`@("`@("`@
M("`@(&)I;FUO9&4H1DE,12D["B`@("`@("`@("`@("`@("`D8V]N=&5N="`]
M(#Q&24Q%/CL*("`@("`@("`@("`@("`@(&-L;W-E($9)3$4["@H@("`@("`@
M("`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD
M8V]N=&5N="P@)&9I;&4I"B`@("`@("`@("`@("`@("`@("`@:68@(21%3E9[
M4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I
M.PH*("`@("`@("`@("`@("`@(",@1&\@;F]T(&QE="!84TQO861E<B!P:6-K
M('5P(&%U=&\O*B!F<F]M(&5N=FER;VYM96YT"B`@("`@("`@("`@("`@("`D
M8V]N=&5N="`]?B!S+V=O=&\@*W)E=')Y("MU;FQE<W,@*RXJ+V=O=&\@<F5T
M<GD[+PH@("`@("`@("`@("`@("`@("`@(&EF(&QC*"1N86UE*2!E<2!L8R@B
M6%-,;V%D97(N<&TB*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;W5T
M<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*("`@("`@("`@("`@)&9H+3YP
M<FEN="@B1DE,12(I.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG
M+"!L96YG=&@H)&YA;64I("L@.2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT
M*'-P<FEN=&8H"B`@("`@("`@("`@("`@("`B)3`X>"\E<R(L($%R8VAI=F4Z
M.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64*("`@("`@("`@
M("`@*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T
M:"@D8V]N=&5N="DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@D8V]N=&5N
M="D["B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*"B`@("`C($YO=R!W<FET
M92!O=70@=&AE(%!!4B!A;F0@;6%G:6,@<W1R:6YG<R![>WL*("`@("1Z:7`M
M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*"B`@("`D8V%C:&5?
M;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["B`@("!I9B`H(21C
M86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*
M("`@("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[
M($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("!\?"!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@
M("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S
M=#HZ340U+3YN97<@?3L*"B`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@
M:6X@1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@(&UY("1S:&%?
M=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P
M.PH@("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?
M=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@)&-T>"T^861D9FEL
M92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("!]"B`@("`@("`@96QS
M92!["B`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD
M;W5T(BDI('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@
M("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@
M(&-L;W-E*"1F:"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@
M("1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM
M93L*("`@('T*("`@("1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG
M=&@@)&-A8VAE7VYA;64I.PH@("`@)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*
M("`@("1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PH@("`@)&9H+3YP<FEN="AP
M86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B`@("`D
M9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B`@("`D9F@M/F-L;W-E.PH@("`@
M8VAM;V0@,#<U-2P@)&]U=#L*("`@(",@?7U]"@H@("`@97AI=#L*?0HC('U]
M?0H*(R!0<F5P87)E("1P<F]G;F%M92!I;G1O(%!!4B!F:6QE(&-A8VAE('M[
M>PI["B`@("!L87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["@H@("`@
M7V9I>%]P<F]G;F%M92@I.PH*("`@(",@3F]W(&QO860@=&AE(%!!4B!F:6QE
M(&%N9"!P=70@:70@:6YT;R!005(Z.DQI8D-A8VAE('M[>PH@("`@<F5Q=6ER
M92!005(["B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H*
M("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?
M7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@1FEL93HZ
M1FEN9#L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*("`@
M(&UY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@(&UY("1F:"`]($E/
M.CI&:6QE+3YN97<["B`@("`D9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G
M*2!O<B!D:64@(B0A.B`D0"(["B`@("`D>FEP+3YR96%D1G)O;49I;&5(86YD
M;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O
M<B!D:64@(B0A.B`D0"(["@H@("`@<'5S:"!`4$%2.CI,:6)#86-H92P@)'II
M<#L*("`@("1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PH*("`@
M("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["B`@("!O=71S*'%Q*%PD14Y6
M>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*"B`@("!I9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI
M<R!P;VEN="$*("`@("`@("!F;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM
M96UB97)S("D@>PH@("`@("`@("`@("!N97AT(&EF("1M96UB97(M/FES1&ER
M96-T;W)Y.PH@("`@("`@("`@("!M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R
M+3YF:6QE3F%M93L*("`@("`@("`@("`@;F5X="!U;FQE<W,@)&UE;6)E<E]N
M86UE(#U^(&U["B`@("`@("`@("`@("`@("!>"B`@("`@("`@("`@("`@("`O
M/W-H;&EB+PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E
M<G-I;VY]+RD_"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[
M87)C:&YA;65]+RD_"B`@("`@("`@("`@("`@("`H6UXO72LI"B`@("`@("`@
M("`@("`@("`D"B`@("`@("`@("`@('UX.PH@("`@("`@("`@("!M>2`D97AT
M<F%C=%]N86UE(#T@)#$["B`@("`@("`@("`@(&UY("1D97-T7VYA;64@/2!&
M:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N
M86UE*3L*("`@("`@("`@("`@:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]
M/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*("`@("`@("`@("`@
M("`@(&]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@
M86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@
M('T@96QS92!["B`@("`@("`@("`@("`@("`D;65M8F5R+3YE>'1R86-T5&]&
M:6QE3F%M960H)&1E<W1?;F%M92D["B`@("`@("`@("`@("`@("!O=71S*'%Q
M*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"B`@("`C('U]?0I]"B,@
M?7U]"@HC($EF('1H97)E)W,@;F\@;6%I;BYP;"!T;R!R=6XL('-H;W<@=7-A
M9V4@>WM["G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PH@
M("`@9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB
M+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P
M<F]G<F%M+G!L(%T*("`@("`@("0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S
M<F,N<&%R"BX*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]
M("0P(#T@<VAI9G0H0$%21U8I.PI]"B,@?7U]"@IS=6(@0W)E871E4&%T:"![
M"B`@("!M>2`H)&YA;64I(#T@0%\["B`@("`*("`@(')E<75I<F4@1FEL93HZ
M0F%S96YA;64["B`@("!M>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&
M:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["B`@
M("`*("`@(')E<75I<F4@1FEL93HZ4&%T:#L*("`@(`H@("`@1FEL93HZ4&%T
M:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D
M:65S('=I=&@@97)R;W(*?0H*<W5B(')E<75I<F5?;6]D=6QE<R!["B`@("`C
M;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU3
M5VEN,S(G.PH*("`@(')E<75I<F4@;&EB.PH@("`@<F5Q=6ER92!$>6YA3&]A
M9&5R.PH@("`@<F5Q=6ER92!I;G1E9V5R.PH@("`@<F5Q=6ER92!S=')I8W0[
M"B`@("!R97%U:7)E('=A<FYI;F=S.PH@("`@<F5Q=6ER92!V87)S.PH@("`@
M<F5Q=6ER92!#87)P.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CL*
M("`@(')E<75I<F4@1F-N=&P["B`@("!R97%U:7)E($9I;&4Z.E1E;7`["B`@
M("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!R97%U:7)E(%A33&]A9&5R.PH@
M("`@<F5Q=6ER92!#;VYF:6<["B`@("!R97%U:7)E($E/.CI(86YD;&4["B`@
M("!R97%U:7)E($E/.CI&:6QE.PH@("`@<F5Q=6ER92!#;VUP<F5S<SHZ6FQI
M8CL*("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@<F5Q=6ER92!005([
M"B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E(%!!4CHZ1&ES
M=#L*("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@979A
M;"![(')E<75I<F4@0W=D('T["B`@("!E=F%L('L@<F5Q=6ER92!7:6XS,B!]
M.PH@("`@979A;"![(')E<75I<F4@5VEN,S(Z.E!R;V-E<W,@?3L*("`@(&5V
M86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PH@("`@979A;"![(')E<75I
M<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["GT*"B,@5&AE($,@=F5R<VEO
M;B!O9B!T:&ES(&-O9&4@87!P96%R<R!I;B!M>6QD<B]M:W1M<&1I<BYC"G-U
M8B!?<V5T7W!A<E]T96UP('L*("`@(&EF("@D14Y6>U!!4E]414U0?2!A;F0@
M)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!A<E]T96UP
M(#T@)#$["B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@(&9O<F5A8V@@;7D@
M)'!A=&@@*`H@("`@("`@("AM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2
M(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`H@("`@("`@('%W*"!#.EQ<
M5$5-4"`O=&UP("X@*0H@("`@*2!["B`@("`@("`@;F5X="!U;FQE<W,@)'!A
M=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*("`@("`@("!M>2`D=7-E
M<FYA;64["B`@("`@("`@;7D@)'!W=6ED.PH@("`@("`@(",@9&]E<R!N;W0@
M=V]R:R!E=F5R>7=H97)E.@H@("`@("`@(&5V86P@>R@D<'=U:60I(#T@9V5T
M<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*"B`@("`@("`@:68@*"!D969I
M;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*("`@("`@("`@("`@)'5S97)N
M86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["B`@("`@("`@?0H@("`@("`@(&5L
M<VEF("AD969I;F5D("1P=W5I9"D@>PH@("`@("`@("`@("`D=7-E<FYA;64@
M/2`D<'=U:60["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@
M("`D=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\
M("=365-414TG.PH@("`@("`@('T*("`@("`@("`D=7-E<FYA;64@/7X@<R]<
M5R]?+V<["@H@("`@("`@(&UY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?
M9&5L:6U]<&%R+21U<V5R;F%M92(["B`@("`@("`@;6MD:7(@)'-T;7!D:7(L
M(#`W-34["B`@("`@("`@:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M
M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["B`@("`@("`@("`@(&]P
M96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PH@("`@("`@("`@("!S965K
M("1F:"P@+3$X+"`R.PH@("`@("`@("`@("!S>7-R96%D("1F:"P@;7D@)&)U
M9BP@-CL*("`@("`@("`@("`@:68@*"1B=68@97$@(EPP0T%#2$4B*2!["B`@
M("`@("`@("`@("`@("!S965K("1F:"P@+34X+"`R.PH@("`@("`@("`@("`@
M("`@<WES<F5A9"`D9F@L("1B=68L(#0Q.PH@("`@("`@("`@("`@("`@)&)U
M9B`]?B!S+UPP+R]G.PH@("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#
M;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;7D@)&-T>"`](&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I
M('T*("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@("`@("`@
M("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-
M1#4M/FYE=R!].PH*("`@("`@("`@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@
M8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("`@("`@
M("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%
M4E-)3TX@?2!\?"`P.PH@("`@("`@("`@("`@("`@:68@*"1S:&%?=F5R<VEO
M;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@
M("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I
M(&EF("@D8W1X*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N
M*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PH@("`@("`@("`@("`@("`@("`@
M("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@("`@("1C
M='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@("`@8VQO
M<V4H)&9H*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!]"@H@("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E
M;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I
M;64@*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!C;&]S92@D9F@I.PH@
M("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)$5.5GM005)?
M0TQ%04Y](#T@,3L*("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[
M7V1E;&EM?71E;7`M)"0B.PH@("`@("`@('T*"B`@("`@("`@)$5.5GM005)?
M5$5-4'T@/2`D<W1M<&1I<CL*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*("`@("`@("!L87-T.PH@("`@?0H*("`@("1P87)?=&5M<"`]("0Q(&EF
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\[
M"GT*"G-U8B!?=&5M<&9I;&4@>PH@("`@;7D@*"1E>'0L("1C<F,I(#T@0%\[
M"B`@("!M>2`H)&9H+"`D9FEL96YA;64I.PH*("`@("1F:6QE;F%M92`]("(D
M<&%R7W1E;7`O)&-R8R1E>'0B.PH*("`@(&EF("@D14Y6>U!!4E]#3$5!3GTI
M('L*("`@("`@("!U;FQI;FL@)&9I;&5N86UE(&EF("UE("1F:6QE;F%M93L*
M("`@("`@("!P=7-H($!T;7!F:6QE+"`D9FEL96YA;64["B`@("!]"B`@("!E
M;'-E('L*("`@("`@("!R971U<FX@*'5N9&5F+"`D9FEL96YA;64I(&EF("@M
M<B`D9FEL96YA;64I.PH@("`@?0H*("`@(&]P96X@)&9H+"`G/B<L("1F:6QE
M;F%M92!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["B`@("!R971U<FXH
M)&9H+"`D9FEL96YA;64I.PI]"@IS=6(@7W-E=%]P<F]G;F%M92!["B`@("!I
M9B`H)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@
M/7X@+R@N*RDO*2!["B`@("`@("`@)'!R;V=N86UE(#T@)#$["B`@("!]"@H@
M("`@)'!R;V=N86UE('Q\/2`D,#L*"B`@("!I9B`H)$5.5GM005)?5$5-4'T@
M86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*
M("`@("`@("`D<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["B`@("!]"@H@("`@
M:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D
M0V]N9FEG>U]D96QI;7TI(#X](#`I('L*("`@("`@("!I9B`H;W!E;B!M>2`D
M9F@L("<\)RP@)'!R;V=N86UE*2!["B`@("`@("`@("`@(')E='5R;B!I9B`M
M<R`D9F@["B`@("`@("`@?0H@("`@("`@(&EF("@M<R`B)'!R;V=N86UE)$-O
M;F9I9WM?97AE?2(I('L*("`@("`@("`@("`@)'!R;V=N86UE("X]("1#;VYF
M:6=[7V5X97T["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"B`@("!]
M"@H@("`@9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?
M<V5P?5Q%+RP@)$5.5GM0051(?2D@>PH@("`@("`@(&YE>'0@:68@97AI<W1S
M("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PH@
M("`@("`@("1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PH@("`@
M("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"B`@("`@("`@("`@(&EF("US("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B`@
M("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M92(I+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M92(["B`@("!]"GT*"G-U8B!?9FEX7W!R;V=N86UE
M('L*("`@("0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T[
M"B`@("!I9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@
M,"D@>PH@("`@("`@("1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE(CL*("`@('T*"B`@("`C(%A86"`M(&AA8VL@=&\@;6%K92!05T0@
M=V]R:PH@("`@;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#
M=V0Z.F=E=&-W9"@I"B`@("`@("`@("`@("`@("`Z("@H9&5F:6YE9"`F5VEN
M,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["B`@("!C
M:&]M<"@D<'=D*3L*("`@("1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O
M;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PH*("`@("1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0H*<W5B(%]P87)?:6YI
M=%]E;G8@>PH@("`@:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q
M("D@>PH@("`@("`@(')E='5R;CL*("`@('T@96QS92!["B`@("`@("`@)$5.
M5GM005)?24Y)5$E!3$E:141](#T@,CL*("`@('T*"B`@("!F;W(@*'%W*"!3
M4$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!
M4D=67S`@*2`I('L*("`@("`@("!D96QE=&4@)$5.5GLG4$%27R<N)%]].PH@
M("`@?0H@("`@9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@
M>PH@("`@("`@("1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?
M)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["B`@("!]
M"@H@("`@;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@
M("`@("`@("`@("(["@H@("`@:68@*"1%3E9[4$%27U1%35!]*2!["B`@("`@
M("`@9&5L971E("1%3E9[4$%27T-,14%.?3L*("`@('T*("`@(&5L<VEF("@A
M97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*("`@("`@("!M>2`D
M=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.
M(BDI.PH@("`@("`@("1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]
M?B`O7E!!4E]#3$5!3CTH7%,K*2\["B`@("!]"GT*"G-U8B!O=71S('L*("`@
M(')E='5R;B!I9B`D<75I970["B`@("!I9B`H)&QO9V9H*2!["B`@("`@("`@
M<')I;G0@)&QO9V9H(")`7UQN(CL*("`@('T*("`@(&5L<V4@>PH@("`@("`@
M('!R:6YT(")`7UQN(CL*("`@('T*?0H*<W5B(&EN:71?:6YC('L*("`@(')E
M<75I<F4@0V]N9FEG.PH@("`@<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA
M<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*("`@("`@("!A<F-H;&EB97AP
M('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`H@("`@("`@('9E
M;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"B`@("`I.PI]"@HC(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,*(R!4:&4@;6%I;B!P86-K86=E(&9O<B!S8W)I
M<'0@97AE8W5T:6]N"@IP86-K86=E(&UA:6X["@IR97%U:7)E(%!!4CL*=6YS
M:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?
M87)G<RD["@ID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T
M("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"B`@
M("!U;FQE<W,@+64@)'!R;V=N86UE.PH*9&\@)'!R;V=N86UE.PI#3U)%.CIE
M>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@
M)$`@:68@)$`["@I].PH*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"@I#3U)%
M.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K
M*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["@HQ.PH*(VQI
M;F4@,3`Q-PH*7U]%3D1?7PH``1L#.Q0!```A````M%#__S`!``#M4/__4`$`
M`/M1__]P`0``[E+__Y`!```.4___L`$``)55___0`0``^%7___`!```:5___
M$`(``"57__\P`@``Y5G__U`"```V6O__<`(``(Y;__^0`@``?UW__[`"``#C
M7?__T`(``-F%___P`@``4X;__Q`#``"KA___,`,``&2)__]0`P``NXK__W`#
M``#^BO__D`,``#V,__^P`P``7Y3__]`#``#$E?__\`,``#R6__\0!```<)C_
M_S`$``"_F/__4`0``*V=__]P!````)[__Y`$```HH?__R`0``$BA___@!```
M6*'___@$``#HH?__(`4``/BA__\X!0```````!0``````````7I2``%X$`$#
M#`<(D`$``!P````<````+"9``#D`````00X0A@)##08`````````'````#P`
M``!E)D``#@$```!!#A"&`D,-!DB#`P`````<````7````',G0`#S`````$$.
M$(8"0PT&`````````!P```!\````9BA``"``````00X0A@)##08`````````
M'````)P```"&*$``AP(```!!#A"&`D,-!D6#`P`````<````O`````TK0`!C
M`````$$.$(8"0PT&`````````!P```#<````<"M``"(!````00X0A@)##08`
M````````'````/P```"2+$``"P````!!#A"&`D,-!@`````````<````'`$`
M`)TL0`#``@```$$.$(8"0PT&`````````!P````\`0``72]``%$`````00X0
MA@)##08`````````'````%P!``"N+T``6`$```!!#A"&`D,-!@`````````<
M````?`$```8Q0`#Q`0```$$.$(8"0PT&`````````!P```"<`0``]S)``&0`
M````00X0A@)##08`````````'````+P!``!;,T``]B<```!!#A"&`D,-!@``
M```````<````W`$``%%;0`!Z`````$$.$(8"0PT&`````````!P```#\`0``
MRUM``%@!````00X0A@)##08`````````'````!P"```C74``N0$```!!#A"&
M`D,-!@`````````<````/`(``-Q>0`!7`0```$$.$(8"0PT&`````````!P`
M``!<`@``,V!``$,`````00X0A@)##08`````````'````'P"``!V8$``/P$`
M``!!#A"&`D,-!D6#`P`````<````G`(``+5A0``B"````$$.$(8"0PT&2(,#
M`````!P```"\`@``UVE``&4!````00X0A@)##09(@P,`````'````-P"```\
M:T``>`````!!#A"&`D,-!@`````````<````_`(``+1K0``T`@```$$.$(8"
M0PT&18,#`````!P````<`P``Z&U``$\`````00X0A@)##08`````````'```
M`#P#```W;D``[@0```!!#A"&`D,-!D>#!(P#```<````7`,``"5S0`!3````
M`$$.$(8"0PT&`````````!P```!\`P``>'-``!P#````00X0A@)##08`````
M````%``````````!>E(``7@0`1L,!PB0`0``%````!P```!8G/__&@``````
M````````%````#0```!@G/__`@``````````````)````$P```!8G/__B0``
M``!*CP*&!F8.0(,'C@.-!(P%`````````!0```!T````P)S__Q``````````
M`````!0```",````N)S__Q``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#__________P``````````__________\`````````
M`````````````0`````````!``````````$`````````L@(````````!````
M`````+T"`````````0````````#'`@````````$`````````!0,````````!
M`````````"D$````````#`````````!`($````````T`````````N'=`````
M```$`````````$`"0```````]?[_;P````"8!4````````4`````````H!%`
M```````&`````````/`&0```````"@````````#*!0````````L`````````
M&``````````5`````````````````````P`````````@XF````````(`````
M````.`<````````4``````````<`````````%P`````````(&4````````<`
M````````P!A````````(`````````$@`````````"0`````````8````````
M`/[__V\`````4!A```````#___]O``````(`````````\/__;P````!J%T``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````*.!@````````````````````````````;B!`
M``````!^($```````(X@0```````GB!```````"N($```````+X@0```````
MSB!```````#>($```````.X@0```````_B!````````.(4```````!XA0```
M````+B%````````^(4```````$XA0```````7B%```````!N(4```````'XA
M0```````CB%```````">(4```````*XA0```````OB%```````#.(4``````
M`-XA0```````[B%```````#^(4````````XB0```````'B)````````N(D``
M`````#XB0```````3B)```````!>(D```````&XB0```````?B)```````".
M(D```````)XB0```````KB)```````"^(D```````,XB0```````WB)`````
M``#N(D```````/XB0```````#B-````````>(T```````"XC0```````/B-`
M``````!.(T```````%XC0```````;B-```````!^(T```````(XC0```````
MGB-```````"N(T```````+XC0```````SB-```````#>(T```````.XC0```
M````_B-````````.)$```````!XD0```````+B1````````^)$```````$XD
M0```````7B1```````!N)$```````'XD0```````CB1```````">)$``````
M`*XD0```````OB1```````#.)$```````-XD0```````[B1```````#^)$``
M``````XE0```````'B5````````N)4`````````````````````````````=
M>$```````!]X0```````_____P````"@>D```````+=:`````````$=#0SH@
M*%5B=6YT=2`T+C,N,"TT=6)U;G1U,2D@-"XS+C$@,C`P.#`U,#D@*'!R97)E
M;&5A<V4I``!'0T,Z("A58G5N='4@-"XS+C`M-'5B=6YT=3$I(#0N,RXQ(#(P
M,#@P-3`Y("AP<F5R96QE87-E*0``1T-#.B`H56)U;G1U(#0N,RXP+31U8G5N
M='4Q*2`T+C,N,2`R,#`X,#4P.2`H<')E<F5L96%S92D``$=#0SH@*%5B=6YT
M=2`T+C,N,"TT=6)U;G1U,2D@-"XS+C$@,C`P.#`U,#D@*'!R97)E;&5A<V4I
M``!'0T,Z("A58G5N='4@-"XS+C`M-'5B=6YT=3$I(#0N,RXQ(#(P,#@P-3`Y
M("AP<F5R96QE87-E*0``1T-#.B`H56)U;G1U(#0N,RXP+31U8G5N='4Q*2`T
M+C,N,2`R,#`X,#4P.2`H<')E<F5L96%S92D``$=#0SH@*%5B=6YT=2`T+C,N
M,"TT=6)U;G1U,2D@-"XS+C$@,C`P.#`U,#D@*'!R97)E;&5A<V4I``!'0T,Z
M("A58G5N='4@-"XS+C`M-'5B=6YT=3$I(#0N,RXQ(#(P,#@P-3`Y("AP<F5R
M96QE87-E*0``1T-#.B`H56)U;G1U(#0N,RXP+31U8G5N='4Q*2`T+C,N,2`R
M,#`X,#4P.2`H<')E<F5L96%S92D``$=#0SH@*%5B=6YT=2`T+C,N,"TT=6)U
M;G1U,2D@-"XS+C$@,C`P.#`U,#D@*'!R97)E;&5A<V4I``!'0T,Z("A58G5N
M='4@-"XS+C`M-'5B=6YT=3$I(#0N,RXQ(#(P,#@P-3`Y("AP<F5R96QE87-E
M*0``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N9VYU+FAA<V@`
M+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N
M<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`
M+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+F-T;W)S`"YD=&]R<P`N:F-R`"YD
M>6YA;6EC`"YG;W0`+F=O="YP;'0`+F1A=&$`+F)S<P`N8V]M;65N=```````
M````````````````````````````````````````````````````````````
M``````````````````````````````L````!`````@```````````D``````
M```"````````'`````````````````````$````````````````````3````
M!P````(`````````'`)````````<`@```````"`````````````````````$
M````````````````````)0````4````"`````````$`"0```````0`(`````
M``!4`P````````4`````````"``````````$`````````"$```#V__]O`@``
M``````"8!4```````)@%````````6`$````````%``````````@`````````
M```````````K````"P````(`````````\`9```````#P!@```````+`*````
M````!@````$````(`````````!@`````````,P````,````"`````````*`1
M0```````H!$```````#*!0```````````````````0``````````````````
M`#L```#___]O`@````````!J%T```````&H7````````Y``````````%````
M``````(``````````@````````!(````_O__;P(`````````4!A```````!0
M&````````'``````````!@````(````(````````````````````5P````0`
M```"`````````,`80```````P!@```````!(``````````4`````````"```
M```````8`````````&$````$`````@`````````(&4````````@9````````
M.`<````````%````#`````@`````````&`````````!K`````0````8`````
M````0"!```````!`(````````!@````````````````````$````````````
M````````9@````$````&`````````%@@0```````6"````````#@!```````
M````````````!``````````0`````````'$````!````!@````````!`)4``
M`````$`E````````>%(``````````````````!````````````````````!W
M`````0````8`````````N'=```````"X=P````````X`````````````````
M```$````````````````````?0````$````"`````````.!W0```````X'<`
M``````"870``````````````````(````````````````````(4````!````
M`@````````!XU4```````'C5````````%`$```````````````````0`````
M``````````````"3`````0````(`````````D-9```````"0U@```````#P$
M```````````````````(````````````````````G0````$````#````````
M``#@8````````.`````````0````````````````````"```````````````
M`````*0````!`````P`````````0X&```````!#@````````$```````````
M``````````@```````````````````"K`````0````,`````````(.!@````
M```@X`````````@````````````````````(````````````````````L```
M``8````#`````````"C@8```````*.````````#P`0````````8`````````
M"``````````0`````````+D````!`````P`````````8XF```````!CB````
M````"`````````````````````@`````````"`````````"^`````0````,`
M````````(.)@```````@X@```````(`"```````````````````(````````
M``@`````````QP````$````#`````````*#D8```````H.0````````X````
M````````````````"````````````````````,T````(`````P````````#@
MY&```````-CD````````@!```````````````````"``````````````````
M``#2`````0````````````````````````#8Y````````'X"````````````
M```````!`````````````````````0````,`````````````````````````
H5N<```````#;`````````````````````0``````````````````````
